@@ -96,7 +96,9 @@ finished_lookup (void)
 		merging_queue = g_list_remove_link (merging_queue, merging_queue);
 
 		running_merge_requests++;
-		eab_contact_locate_match_full (lookup->book_client, lookup->contact, lookup->avoid, match_query_callback, lookup);
+		eab_contact_locate_match_full (
+			lookup->book_client, lookup->contact,
+			lookup->avoid, match_query_callback, lookup);
 	}
 }
 
@@ -112,7 +114,10 @@ free_lookup (EContactMergingLookup *lookup)
 }
 
 static void
-final_id_cb (EBookClient *book_client, const GError *error, const gchar *id, gpointer closure)
+final_id_cb (EBookClient *book_client,
+             const GError *error,
+             const gchar *id,
+             gpointer closure)
 {
 	EContactMergingLookup *lookup = closure;
 
@@ -125,12 +130,19 @@ final_id_cb (EBookClient *book_client, const GError *error, const gchar *id, gpo
 }
 
 static void
-final_cb_as_id (EBookClient *book_client, const GError *error, gpointer closure)
+final_cb_as_id (EBookClient *book_client,
+                const GError *error,
+                gpointer closure)
 {
 	EContactMergingLookup *lookup = closure;
 
 	if (lookup->id_cb)
-		lookup->id_cb (lookup->book_client, error, lookup->contact ? e_contact_get_const (lookup->contact, E_CONTACT_UID) : NULL, lookup->closure);
+		lookup->id_cb (
+			lookup->book_client, error,
+			lookup->contact ?
+				e_contact_get_const (
+				lookup->contact, E_CONTACT_UID) : NULL,
+			lookup->closure);
 
 	free_lookup (lookup);
 
@@ -138,7 +150,9 @@ final_cb_as_id (EBookClient *book_client, const GError *error, gpointer closure)
 }
 
 static void
-final_cb (EBookClient *book_client, const GError *error, gpointer closure)
+final_cb (EBookClient *book_client,
+          const GError *error,
+          gpointer closure)
 {
 	EContactMergingLookup *lookup = closure;
 
@@ -151,7 +165,9 @@ final_cb (EBookClient *book_client, const GError *error, gpointer closure)
 }
 
 static void
-modify_contact_ready_cb (GObject *source_object, GAsyncResult *result, gpointer user_data)
+modify_contact_ready_cb (GObject *source_object,
+                         GAsyncResult *result,
+                         gpointer user_data)
 {
 	EBookClient *book_client = E_BOOK_CLIENT (source_object);
 	EContactMergingLookup *lookup = user_data;
@@ -172,7 +188,9 @@ modify_contact_ready_cb (GObject *source_object, GAsyncResult *result, gpointer
 }
 
 static void
-add_contact_ready_cb (GObject *source_object, GAsyncResult *result, gpointer user_data)
+add_contact_ready_cb (GObject *source_object,
+                      GAsyncResult *result,
+                      gpointer user_data)
 {
 	EBookClient *book_client = E_BOOK_CLIENT (source_object);
 	EContactMergingLookup *lookup = user_data;
@@ -192,7 +210,8 @@ add_contact_ready_cb (GObject *source_object, GAsyncResult *result, gpointer use
 }
 
 static void
-doit (EContactMergingLookup *lookup, gboolean force_modify)
+doit (EContactMergingLookup *lookup,
+      gboolean force_modify)
 {
 	if (lookup->op == E_CONTACT_MERGING_ADD) {
 		if (force_modify)
@@ -218,7 +237,9 @@ cancelit (EContactMergingLookup *lookup)
 }
 
 static void
-dialog_map (GtkWidget *window, GdkEvent *event, GtkWidget *table)
+dialog_map (GtkWidget *window,
+            GdkEvent *event,
+            GtkWidget *table)
 {
 	GtkAllocation allocation;
 	gint h, w;
@@ -238,7 +259,8 @@ dialog_map (GtkWidget *window, GdkEvent *event, GtkWidget *table)
 }
 
 static void
-dropdown_changed (GtkWidget *dropdown, dropdown_data *data)
+dropdown_changed (GtkWidget *dropdown,
+                  dropdown_data *data)
 {
 	gchar *str;
 	str = gtk_combo_box_text_get_active_text (GTK_COMBO_BOX_TEXT (dropdown));
@@ -251,7 +273,9 @@ dropdown_changed (GtkWidget *dropdown, dropdown_data *data)
 }
 
 static void
-remove_contact_ready_cb (GObject *source_object, GAsyncResult *result, gpointer user_data)
+remove_contact_ready_cb (GObject *source_object,
+                         GAsyncResult *result,
+                         gpointer user_data)
 {
 	EBookClient *book_client = E_BOOK_CLIENT (source_object);
 	EContactMergingLookup *lookup = user_data;
@@ -262,12 +286,16 @@ remove_contact_ready_cb (GObject *source_object, GAsyncResult *result, gpointer
 
 	e_book_client_remove_contact_finish (book_client, result, &error);
 
-	if (error) {
-		g_debug ("%s: Failed to remove contact: %s", G_STRFUNC, error->message);
+	if (error != NULL) {
+		g_warning (
+			"%s: Failed to remove contact: %s",
+			G_STRFUNC, error->message);
 		g_error_free (error);
 	}
 
-	e_book_client_add_contact (book_client, lookup->contact, NULL, add_contact_ready_cb, lookup);
+	e_book_client_add_contact (
+		book_client, lookup->contact, NULL,
+		add_contact_ready_cb, lookup);
 }
 
 static gint
@@ -333,7 +361,7 @@ mergeit (EContactMergingLookup *lookup)
 						use_field = E_CONTACT_EMAIL_2;
 						break;
 					}
-					else/*Either the new contact has no email OR the email already exist in the duplicate contact*/
+					else/*Either the new contact has no email OR the email already exist in the duplicate contact */
 						continue;
 				case 2:
 					/*New contact has email and it is equal to neither of the 2 emails in the duplicate contact*/
@@ -357,7 +385,7 @@ mergeit (EContactMergingLookup *lookup)
 				}
 				label = gtk_label_new (_("Email"));
 				hbox = gtk_hbox_new (FALSE, 0);
-				gtk_box_pack_start (GTK_BOX (hbox), (GtkWidget*) label, FALSE, FALSE, 0);
+				gtk_box_pack_start (GTK_BOX (hbox), (GtkWidget *) label, FALSE, FALSE, 0);
 				gtk_table_attach_defaults (table, (GtkWidget *) hbox, 0, 1, row, row + 1);
 
 				dropdown = gtk_combo_box_text_new ();
@@ -374,7 +402,7 @@ mergeit (EContactMergingLookup *lookup)
 				g_signal_connect (dropdown, "changed", G_CALLBACK(dropdown_changed), data);
 
 				hbox = gtk_hbox_new (FALSE, 0);
-				gtk_box_pack_start (GTK_BOX (hbox), (GtkWidget*) dropdown, FALSE, FALSE, 0);
+				gtk_box_pack_start (GTK_BOX (hbox), (GtkWidget *) dropdown, FALSE, FALSE, 0);
 				gtk_table_attach_defaults (table, (GtkWidget *) hbox, 1, 2, row, row + 1);
 				gtk_widget_show ((GtkWidget *) dropdown);
 				continue;
@@ -383,13 +411,13 @@ mergeit (EContactMergingLookup *lookup)
 				row++;
 				label = gtk_label_new (e_contact_pretty_name (field));
 				hbox = gtk_hbox_new (FALSE, 0);
-				gtk_box_pack_start (GTK_BOX (hbox), (GtkWidget*) label, FALSE, FALSE, 0);
+				gtk_box_pack_start (GTK_BOX (hbox), (GtkWidget *) label, FALSE, FALSE, 0);
 				gtk_table_attach_defaults (table, (GtkWidget *) hbox, 0, 1, row, row + 1);
 
 				label = gtk_label_new (string);
 				hbox = gtk_hbox_new (FALSE, 0);
-				gtk_box_pack_start (GTK_BOX (hbox), (GtkWidget*) label, FALSE, FALSE, 0);
-				gtk_table_attach_defaults (table, (GtkWidget*) hbox, 1, 2, row, row + 1);
+				gtk_box_pack_start (GTK_BOX (hbox), (GtkWidget *) label, FALSE, FALSE, 0);
+				gtk_table_attach_defaults (table, (GtkWidget *) hbox, 1, 2, row, row + 1);
 				continue;
 			}
 
@@ -398,7 +426,7 @@ mergeit (EContactMergingLookup *lookup)
 				row++;
 				label = gtk_label_new (e_contact_pretty_name (field));
 				hbox = gtk_hbox_new (FALSE, 0);
-				gtk_box_pack_start (GTK_BOX (hbox), (GtkWidget*) label, FALSE, FALSE, 0);
+				gtk_box_pack_start (GTK_BOX (hbox), (GtkWidget *) label, FALSE, FALSE, 0);
 				gtk_table_attach_defaults (table, (GtkWidget *) hbox, 0, 1, row, row + 1);
 				data = g_new0 (dropdown_data, 1);
 				dropdown = gtk_combo_box_text_new ();
@@ -419,7 +447,7 @@ mergeit (EContactMergingLookup *lookup)
 
 				g_signal_connect (dropdown, "changed", G_CALLBACK(dropdown_changed), data);
 				hbox = gtk_hbox_new (FALSE, 0);
-				gtk_box_pack_start (GTK_BOX (hbox), (GtkWidget*) dropdown, FALSE, FALSE, 0);
+				gtk_box_pack_start (GTK_BOX (hbox), (GtkWidget *) dropdown, FALSE, FALSE, 0);
 				gtk_table_attach_defaults (table, (GtkWidget *) hbox, 1, 2, row, row + 1);
 				gtk_widget_show_all ((GtkWidget *) dropdown);
 			}
@@ -436,7 +464,8 @@ mergeit (EContactMergingLookup *lookup)
 
 	switch (result) {
 	case GTK_RESPONSE_OK:
-		     lookup->contact = lookup->match;
+		     g_object_unref (lookup->contact);
+		     lookup->contact = g_object_ref (lookup->match);
 		     e_book_client_remove_contact (lookup->book_client, lookup->match, NULL, remove_contact_ready_cb, lookup);
 		     value = 1;
 		     break;
@@ -451,7 +480,8 @@ mergeit (EContactMergingLookup *lookup)
 }
 
 static gboolean
-check_if_same (EContact *contact, EContact *match)
+check_if_same (EContact *contact,
+               EContact *match)
 {
 	EContactField field;
 	GList *email_attr_list;
@@ -463,7 +493,7 @@ check_if_same (EContact *contact, EContact *match)
 		num_of_email = g_list_length (email_attr_list);
 
 		if ((field == E_CONTACT_EMAIL_1 || field == E_CONTACT_EMAIL_2
-		     || field == E_CONTACT_EMAIL_3 || field == E_CONTACT_EMAIL_4) && (num_of_email<4)) {
+		     || field == E_CONTACT_EMAIL_3 || field == E_CONTACT_EMAIL_4) && (num_of_email < 4)) {
 			str = (gchar *) e_contact_get_const (contact, field);
 			switch (num_of_email)
 			{
@@ -498,7 +528,9 @@ check_if_same (EContact *contact, EContact *match)
 }
 
 static void
-response (GtkWidget *dialog, gint response, EContactMergingLookup *lookup)
+response (GtkWidget *dialog,
+          gint response,
+          EContactMergingLookup *lookup)
 {
 	static gint merge_response;
 
@@ -523,7 +555,10 @@ response (GtkWidget *dialog, gint response, EContactMergingLookup *lookup)
 }
 
 static void
-match_query_callback (EContact *contact, EContact *match, EABContactMatchType type, gpointer closure)
+match_query_callback (EContact *contact,
+                      EContact *match,
+                      EABContactMatchType type,
+                      gpointer closure)
 {
 	EContactMergingLookup *lookup = closure;
 	gint flag;
@@ -607,9 +642,9 @@ match_query_callback (EContact *contact, EContact *match, EABContactMatchType ty
 
 gboolean
 eab_merging_book_add_contact (EBookClient *book_client,
-			      EContact *contact,
-			      EABMergingIdAsyncCallback cb,
-			      gpointer closure)
+                              EContact *contact,
+                              EABMergingIdAsyncCallback cb,
+                              gpointer closure)
 {
 	EContactMergingLookup *lookup;
 
@@ -630,9 +665,9 @@ eab_merging_book_add_contact (EBookClient *book_client,
 
 gboolean
 eab_merging_book_modify_contact (EBookClient *book_client,
-				 EContact *contact,
-				 EABMergingAsyncCallback cb,
-				 gpointer closure)
+                                 EContact *contact,
+                                 EABMergingAsyncCallback cb,
+                                 gpointer closure)
 {
 	EContactMergingLookup *lookup;
 
@@ -653,9 +688,9 @@ eab_merging_book_modify_contact (EBookClient *book_client,
 
 gboolean
 eab_merging_book_find_contact (EBookClient *book_client,
-			       EContact *contact,
-			       EABMergingContactAsyncCallback cb,
-			       gpointer closure)
+                               EContact *contact,
+                               EABMergingContactAsyncCallback cb,
+                               gpointer closure)
 {
 	EContactMergingLookup *lookup;
 
