@@ -29,15 +29,13 @@
  **/
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include <config.h>
 #endif
 
 #include <string.h>
 #include <time.h>
 
-#include <glib.h>
 #include <glib/gi18n.h>
-#include <glib-object.h>
 #include <glib/gstdio.h>
 
 #include <libedataserver/e-data-server-util.h>
@@ -50,6 +48,7 @@
 #include "mail-tools.h"
 
 #include "em-utils.h"
+#include "e-mail-folder-utils.h"
 #include "e-mail-local.h"
 #include "e-mail-session.h"
 #include "e-mail-store-utils.h"
@@ -91,7 +90,6 @@ struct _folder_info {
 	struct _store_info *store_info;	/* 'parent' link */
 
 	gchar *full_name;	/* full name of folder/folderinfo */
-	gchar *uri;		/* uri of folder */
 
 	guint32 flags;
 	gboolean has_children;
@@ -108,9 +106,7 @@ struct _folder_update {
 	guint new;     /* new mail arrived? */
 
 	gchar *full_name;
-	gchar *uri;
 	gchar *oldfull;
-	gchar *olduri;
 
 	gint unread;
 	CamelStore *store;
@@ -123,8 +119,6 @@ struct _folder_update {
 
 struct _store_info {
 	GHashTable *folders;	/* by full_name */
-	GHashTable *folders_uri; /* by uri */
-
 	CamelStore *store;	/* the store for these folders */
 
 	/* Outstanding folderinfo requests */
@@ -137,11 +131,9 @@ static void
 free_update (struct _folder_update *up)
 {
 	g_free (up->full_name);
-	g_free (up->uri);
 	if (up->store)
 		g_object_unref (up->store);
 	g_free (up->oldfull);
-	g_free (up->olduri);
 	g_free (up->msg_uid);
 	g_free (up->msg_sender);
 	g_free (up->msg_subject);
@@ -159,16 +151,24 @@ flush_updates_idle_cb (MailFolderCache *self)
 
 		if (up->remove) {
 			if (up->delete) {
-				g_signal_emit (self, signals[FOLDER_DELETED], 0, up->store, up->uri);
+				g_signal_emit (
+					self, signals[FOLDER_DELETED], 0,
+					up->store, up->full_name);
 			} else
-				g_signal_emit (self, signals[FOLDER_UNAVAILABLE], 0, up->store, up->uri);
+				g_signal_emit (
+					self, signals[FOLDER_UNAVAILABLE], 0,
+					up->store, up->full_name);
 		} else {
-			if (up->olduri && up->add) {
-				g_signal_emit (self, signals[FOLDER_RENAMED], 0, up->store, up->olduri, up->uri);
+			if (up->oldfull && up->add) {
+				g_signal_emit (
+					self, signals[FOLDER_RENAMED], 0,
+					up->store, up->oldfull, up->full_name);
 			}
 
-			if (!up->olduri && up->add)
-				g_signal_emit (self, signals[FOLDER_AVAILABLE], 0, up->store, up->uri);
+			if (!up->oldfull && up->add)
+				g_signal_emit (
+					self, signals[FOLDER_AVAILABLE], 0,
+					up->store, up->full_name);
 		}
 
 		/* update unread counts */
@@ -176,10 +176,10 @@ flush_updates_idle_cb (MailFolderCache *self)
 			       up->store, up->full_name, up->unread);
 
 		/* indicate that the folder has changed (new mail received, etc) */
-		if (up->uri) {
+		if (up->store != NULL && up->full_name != NULL) {
 			g_signal_emit (
 				self, signals[FOLDER_CHANGED], 0, up->store,
-				up->uri, up->full_name, up->new, up->msg_uid,
+				up->full_name, up->new, up->msg_uid,
 				up->msg_sender, up->msg_subject);
 		}
 
@@ -262,19 +262,26 @@ update_1folder (MailFolderCache *self,
 
 	folder = mfi->folder;
 	if (folder) {
-		gboolean is_drafts = FALSE, is_outbox = FALSE;
+		gboolean folder_is_sent;
+		gboolean folder_is_drafts;
+		gboolean folder_is_outbox;
+		gboolean folder_is_vtrash;
+		gboolean special_case;
 
-		d(printf("update 1 folder '%s'\n", folder->full_name));
-		if ((self->priv->count_trash && (CAMEL_IS_VTRASH_FOLDER (folder)))
-		    || (is_drafts = em_utils_folder_is_drafts (
-			folder, info ? info->uri : NULL))
-		    || (is_outbox = em_utils_folder_is_outbox (
-			folder, info ? info->uri : NULL))
-		    || (self->priv->count_sent && em_utils_folder_is_sent (
-			folder, info ? info->uri : NULL))) {
+		folder_is_sent = em_utils_folder_is_sent (folder);
+		folder_is_drafts = em_utils_folder_is_drafts (folder);
+		folder_is_outbox = em_utils_folder_is_outbox (folder);
+		folder_is_vtrash = CAMEL_IS_VTRASH_FOLDER (folder);
+
+		special_case =
+			(self->priv->count_trash && folder_is_vtrash) ||
+			(self->priv->count_sent && folder_is_sent) ||
+			folder_is_drafts || folder_is_outbox;
+
+		if (special_case) {
 			d(printf(" total count\n"));
 			unread = camel_folder_get_message_count (folder);
-			if (is_drafts || is_outbox) {
+			if (folder_is_drafts || folder_is_outbox) {
 				guint32 junked = 0;
 
 				if ((deleted = camel_folder_get_deleted_message_count (folder)) > 0)
@@ -291,9 +298,7 @@ update_1folder (MailFolderCache *self,
 			else
 				unread = camel_folder_get_unread_message_count (folder);
 		}
-	} else if (info && !em_utils_folder_is_drafts (NULL, info->uri) &&
-		!em_utils_folder_is_outbox (NULL, info->uri))
-		unread = info->unread;
+	}
 
 	d(printf("folder updated: unread %d: '%s'\n", unread, mfi->full_name));
 
@@ -305,7 +310,6 @@ update_1folder (MailFolderCache *self,
 	up->unread = unread;
 	up->new = new;
 	up->store = g_object_ref (mfi->store_info->store);
-	up->uri = g_strdup (mfi->uri);
 	up->msg_uid = g_strdup (msg_uid);
 	up->msg_sender = g_strdup (msg_sender);
 	up->msg_subject = g_strdup (msg_subject);
@@ -319,7 +323,7 @@ folder_changed_cb (CamelFolder *folder,
                    MailFolderCache *self)
 {
 	static GHashTable *last_newmail_per_folder = NULL;
-	time_t latest_received;
+	time_t latest_received, new_latest_received;
 	CamelFolder *local_drafts;
 	CamelFolder *local_outbox;
 	CamelFolder *local_sent;
@@ -342,6 +346,7 @@ folder_changed_cb (CamelFolder *folder,
 	/* it's fine to hash them by folder pointer here */
 	latest_received = GPOINTER_TO_INT (
 		g_hash_table_lookup (last_newmail_per_folder, folder));
+	new_latest_received = latest_received;
 
 	local_drafts = e_mail_local_get_folder (E_MAIL_LOCAL_FOLDER_DRAFTS);
 	local_outbox = e_mail_local_get_folder (E_MAIL_LOCAL_FOLDER_OUTBOX);
@@ -353,16 +358,18 @@ folder_changed_cb (CamelFolder *folder,
 	    && folder != local_sent
 	    && changes && (changes->uid_added->len > 0)) {
 		/* for each added message, check to see that it is
-		   brand new, not junk and not already deleted */
+		 * brand new, not junk and not already deleted */
 		for (i = 0; i < changes->uid_added->len; i++) {
-			info = camel_folder_get_message_info (folder, changes->uid_added->pdata[i]);
+			info = camel_folder_get_message_info (
+				folder, changes->uid_added->pdata[i]);
 			if (info) {
 				flags = camel_message_info_flags (info);
 				if (((flags & CAMEL_MESSAGE_SEEN) == 0) &&
 				    ((flags & CAMEL_MESSAGE_JUNK) == 0) &&
 				    ((flags & CAMEL_MESSAGE_DELETED) == 0) &&
 				    (camel_message_info_date_received (info) > latest_received)) {
-					latest_received = camel_message_info_date_received (info);
+					if (camel_message_info_date_received (info) > new_latest_received)
+						new_latest_received = camel_message_info_date_received (info);
 					new++;
 					if (new == 1) {
 						uid = g_strdup (camel_message_info_uid (info));
@@ -386,7 +393,7 @@ folder_changed_cb (CamelFolder *folder,
 	if (new > 0)
 		g_hash_table_insert (
 			last_newmail_per_folder, folder,
-			GINT_TO_POINTER (latest_received));
+			GINT_TO_POINTER (new_latest_received));
 
 	g_mutex_lock (self->priv->stores_mutex);
 	if (self->priv->stores != NULL
@@ -430,7 +437,6 @@ unset_folder_info (MailFolderCache *self,
 		up->unsub = unsub;
 		up->store = g_object_ref (mfi->store_info->store);
 		up->full_name = g_strdup (mfi->full_name);
-		up->uri = g_strdup (mfi->uri);
 
 		g_queue_push_tail (&self->priv->updates, up);
 		flush_updates (self);
@@ -441,12 +447,13 @@ static void
 free_folder_info (struct _folder_info *mfi)
 {
 	g_free (mfi->full_name);
-	g_free (mfi->uri);
 	g_free (mfi);
 }
 
 static void
-setup_folder (MailFolderCache *self, CamelFolderInfo *fi, struct _store_info *si)
+setup_folder (MailFolderCache *self,
+              CamelFolderInfo *fi,
+              struct _store_info *si)
 {
 	struct _folder_info *mfi;
 	struct _folder_update *up;
@@ -455,20 +462,16 @@ setup_folder (MailFolderCache *self, CamelFolderInfo *fi, struct _store_info *si
 	if (mfi) {
 		update_1folder (self, mfi, 0, NULL, NULL, NULL, fi);
 	} else {
-		d(printf("Adding new folder: %s (%s)\n", fi->full_name, fi->uri));
 		mfi = g_malloc0 (sizeof (*mfi));
 		mfi->full_name = g_strdup (fi->full_name);
-		mfi->uri = g_strdup (fi->uri);
 		mfi->store_info = si;
 		mfi->flags = fi->flags;
 		mfi->has_children = fi->child != NULL;
 
 		g_hash_table_insert (si->folders, mfi->full_name, mfi);
-		g_hash_table_insert (si->folders_uri, mfi->uri, mfi);
 
 		up = g_malloc0 (sizeof (*up));
 		up->full_name = g_strdup (mfi->full_name);
-		up->uri = g_strdup (fi->uri);
 		up->unread = fi->unread;
 		up->store = g_object_ref (si->store);
 
@@ -481,10 +484,10 @@ setup_folder (MailFolderCache *self, CamelFolderInfo *fi, struct _store_info *si
 }
 
 static void
-create_folders (MailFolderCache *self, CamelFolderInfo *fi, struct _store_info *si)
+create_folders (MailFolderCache *self,
+                CamelFolderInfo *fi,
+                struct _store_info *si)
 {
-	d(printf("Setup new folder: %s\n  %s\n", fi->uri, fi->full_name));
-
 	while (fi) {
 		setup_folder (self, fi, si);
 
@@ -516,7 +519,7 @@ store_folder_created_cb (CamelStore *store,
 {
 	/* We only want created events to do more work
 	 * if we dont support subscriptions. */
-	if (!camel_store_supports_subscriptions (store))
+	if (!CAMEL_IS_SUBSCRIBABLE (store))
 		store_folder_subscribed_cb (store, info, cache);
 }
 
@@ -542,7 +545,6 @@ store_folder_unsubscribed_cb (CamelStore *store,
 		mfi = g_hash_table_lookup (si->folders, info->full_name);
 		if (mfi) {
 			g_hash_table_remove (si->folders, mfi->full_name);
-			g_hash_table_remove (si->folders_uri, mfi->uri);
 			unset_folder_info (self, mfi, TRUE, TRUE);
 			free_folder_info (mfi);
 		}
@@ -557,32 +559,10 @@ store_folder_deleted_cb (CamelStore *store,
 {
 	/* We only want deleted events to do more work
 	 * if we dont support subscriptions. */
-	if (!camel_store_supports_subscriptions (store))
+	if (!CAMEL_IS_SUBSCRIBABLE (store))
 		store_folder_unsubscribed_cb (store, info, self);
 }
 
-static gchar *
-folder_to_url (CamelStore *store, const gchar *full_name)
-{
-	CamelURL *url;
-	gchar *out;
-
-	url = camel_url_copy (((CamelService *)store)->url);
-	if (((CamelService *)store)->provider->url_flags  & CAMEL_URL_FRAGMENT_IS_PATH) {
-		camel_url_set_fragment (url, full_name);
-	} else {
-		gchar *name = g_alloca (strlen (full_name)+2);
-
-		sprintf(name, "/%s", full_name);
-		camel_url_set_path (url, name);
-	}
-
-	out = camel_url_to_string (url, CAMEL_URL_HIDE_ALL);
-	camel_url_free (url);
-
-	return out;
-}
-
 static void
 rename_folders (MailFolderCache *self,
                 struct _store_info *si,
@@ -603,38 +583,28 @@ rename_folders (MailFolderCache *self,
 	old = g_strdup_printf("%s%s", oldbase, fi->full_name + strlen(newbase));
 	mfi = g_hash_table_lookup (si->folders, old);
 	if (mfi) {
-		d(printf("Found old folder '%s' renaming to '%s'\n", mfi->full_name, fi->full_name));
-
 		up->oldfull = mfi->full_name;
-		up->olduri = mfi->uri;
 
 		/* Its a rename op */
 		g_hash_table_remove (si->folders, mfi->full_name);
-		g_hash_table_remove (si->folders_uri, mfi->uri);
 		mfi->full_name = g_strdup (fi->full_name);
-		mfi->uri = g_strdup (fi->uri);
 		mfi->flags = fi->flags;
 		mfi->has_children = fi->child != NULL;
 
 		g_hash_table_insert (si->folders, mfi->full_name, mfi);
-		g_hash_table_insert (si->folders_uri, mfi->uri, mfi);
 	} else {
-		d(printf("Rename found a new folder? old '%s' new '%s'\n", old, fi->full_name));
 		/* Its a new op */
 		mfi = g_malloc0 (sizeof (*mfi));
 		mfi->full_name = g_strdup (fi->full_name);
-		mfi->uri = g_strdup (fi->uri);
 		mfi->store_info = si;
 		mfi->flags = fi->flags;
 		mfi->has_children = fi->child != NULL;
 
 		g_hash_table_insert (si->folders, mfi->full_name, mfi);
-		g_hash_table_insert (si->folders_uri, mfi->uri, mfi);
 	}
 
 	up->full_name = g_strdup (mfi->full_name);
-	up->uri = g_strdup (mfi->uri);
-	up->unread = fi->unread==-1?0:fi->unread;
+	up->unread = fi->unread==-1 ? 0 : fi->unread;
 	up->store = g_object_ref (si->store);
 
 	if ((fi->flags & CAMEL_FOLDER_NOSELECT) == 0)
@@ -651,9 +621,9 @@ rename_folders (MailFolderCache *self,
 
 	/* rename the meta-data we maintain ourselves */
 	config_dir = mail_session_get_config_dir ();
-	olduri = folder_to_url (si->store, old);
+	olduri = e_mail_folder_uri_build (si->store, old);
 	e_filename_make_safe (olduri);
-	newuri = folder_to_url (si->store, fi->full_name);
+	newuri = e_mail_folder_uri_build (si->store, fi->full_name);
 	e_filename_make_safe (newuri);
 	oldfile = g_strdup_printf("%s/custom_view-%s.xml", config_dir, olduri);
 	newfile = g_strdup_printf("%s/custom_view-%s.xml", config_dir, newuri);
@@ -672,7 +642,8 @@ rename_folders (MailFolderCache *self,
 }
 
 static void
-get_folders (CamelFolderInfo *fi, GPtrArray *folders)
+get_folders (CamelFolderInfo *fi,
+             GPtrArray *folders)
 {
 	while (fi) {
 		g_ptr_array_add (folders, fi);
@@ -685,10 +656,11 @@ get_folders (CamelFolderInfo *fi, GPtrArray *folders)
 }
 
 static gint
-folder_cmp (gconstpointer ap, gconstpointer bp)
+folder_cmp (gconstpointer ap,
+            gconstpointer bp)
 {
-	const CamelFolderInfo *a = ((CamelFolderInfo **)ap)[0];
-	const CamelFolderInfo *b = ((CamelFolderInfo **)bp)[0];
+	const CamelFolderInfo *a = ((CamelFolderInfo **) ap)[0];
+	const CamelFolderInfo *b = ((CamelFolderInfo **) bp)[0];
 
 	return strcmp (a->full_name, b->full_name);
 }
@@ -709,12 +681,12 @@ store_folder_renamed_cb (CamelStore *store,
 		gint i;
 
 		/* Ok, so for some reason the folderinfo we have comes in all messed up from
-		   imap, should find out why ... this makes it workable */
+		 * imap, should find out why ... this makes it workable */
 		get_folders (info, folders);
 		qsort (folders->pdata, folders->len, sizeof (folders->pdata[0]), folder_cmp);
 
 		top = folders->pdata[0];
-		for (i=0;i<folders->len;i++) {
+		for (i = 0; i < folders->len; i++) {
 			rename_folders (self, si, old_name, top->full_name, folders->pdata[i]);
 		}
 
@@ -725,53 +697,71 @@ store_folder_renamed_cb (CamelStore *store,
 }
 
 struct _update_data {
-	gint id;			/* id for cancellation */
-	guint cancel:1;		/* also tells us we're cancelled */
-
 	NoteDoneFunc done;
 	gpointer data;
 	MailFolderCache *cache;
+	GCancellable *cancellable;
 };
 
 static void
-unset_folder_info_hash (gchar *path, struct _folder_info *mfi, gpointer data)
+unset_folder_info_hash (gchar *path,
+                        struct _folder_info *mfi,
+                        gpointer data)
 {
-	MailFolderCache *self = (MailFolderCache*) data;
+	MailFolderCache *self = (MailFolderCache *) data;
 	unset_folder_info (self, mfi, FALSE, FALSE);
 }
 
 static void
-free_folder_info_hash (gchar *path, struct _folder_info *mfi, gpointer data)
+free_folder_info_hash (gchar *path,
+                       struct _folder_info *mfi,
+                       gpointer data)
 {
 	free_folder_info (mfi);
 }
 
-static gboolean
-update_folders (CamelStore *store, CamelFolderInfo *fi, gpointer data)
+static void
+update_folders (CamelStore *store,
+                GAsyncResult *result,
+                struct _update_data *ud)
 {
-	struct _update_data *ud = data;
+	CamelFolderInfo *fi;
 	struct _store_info *si;
-	gboolean res = TRUE;
+	GError *error = NULL;
 
-	d(printf("Got folderinfo for store %s\n", store->parent_object.provider->protocol));
+	fi = camel_store_get_folder_info_finish (store, result, &error);
+
+	if (error != NULL) {
+		g_warning ("%s", error->message);
+		g_error_free (error);
+	}
 
 	g_mutex_lock (ud->cache->priv->stores_mutex);
 	si = g_hash_table_lookup (ud->cache->priv->stores, store);
-	if (si && !ud->cancel) {
-		/* the 'si' is still there, so we can remove ourselves from its list */
-		/* otherwise its not, and we're on our own and free anyway */
+	if (si && !g_cancellable_is_cancelled (ud->cancellable)) {
+		/* The 'si' is still there, so we can remove ourselves from
+		 * its list.  Or else its not, and we're on our own and free
+		 * anyway. */
 		g_queue_remove (&si->folderinfo_updates, ud);
 
-		if (fi)
+		if (fi != NULL)
 			create_folders (ud->cache, fi, si);
 	}
 	g_mutex_unlock (ud->cache->priv->stores_mutex);
 
-	if (ud->done)
-		res = ud->done (ud->cache, store, fi, ud->data);
-	g_free (ud);
+	if (fi != NULL) {
+		gboolean free_fi = TRUE;
 
-	return res;
+		if (ud->done != NULL)
+			free_fi = ud->done (ud->cache, store, fi, ud->data);
+		if (free_fi)
+			camel_store_free_folder_info (store, fi);
+	}
+
+	if (ud->cancellable != NULL)
+		g_object_unref (ud->cancellable);
+
+	g_free (ud);
 }
 
 struct _ping_store_msg {
@@ -797,9 +787,14 @@ ping_store_exec (struct _ping_store_msg *m,
                  GCancellable *cancellable,
                  GError **error)
 {
+	CamelServiceConnectionStatus status;
+	CamelService *service;
 	gboolean online = FALSE;
 
-	if (CAMEL_SERVICE (m->store)->status == CAMEL_SERVICE_CONNECTED) {
+	service = CAMEL_SERVICE (m->store);
+	status = camel_service_get_connection_status (service);
+
+	if (status == CAMEL_SERVICE_CONNECTED) {
 		if (CAMEL_IS_DISCO_STORE (m->store) &&
 			camel_disco_store_status (
 			CAMEL_DISCO_STORE (m->store)) !=CAMEL_DISCO_STORE_OFFLINE)
@@ -830,9 +825,14 @@ static MailMsgInfo ping_store_info = {
 static void
 ping_store (CamelStore *store)
 {
+	CamelServiceConnectionStatus status;
+	CamelService *service;
 	struct _ping_store_msg *m;
 
-	if (CAMEL_SERVICE (store)->status != CAMEL_SERVICE_CONNECTED)
+	service = CAMEL_SERVICE (store);
+	status = camel_service_get_connection_status (service);
+
+	if (status != CAMEL_SERVICE_CONNECTED)
 		return;
 
 	m = mail_msg_new (&ping_store_info);
@@ -862,12 +862,21 @@ store_go_online_cb (CamelStore *store,
 
 	g_mutex_lock (ud->cache->priv->stores_mutex);
 
-	if (g_hash_table_lookup (ud->cache->priv->stores, store) != NULL && !ud->cancel) {
-		/* re-use the cancel id.  we're already in the store update list too */
-		ud->id = mail_get_folderinfo (store, NULL, update_folders, ud);
+	if (g_hash_table_lookup (ud->cache->priv->stores, store) != NULL &&
+		!g_cancellable_is_cancelled (ud->cancellable)) {
+		/* We're already in the store update list. */
+		camel_store_get_folder_info (
+			store, NULL,
+			CAMEL_STORE_FOLDER_INFO_FAST |
+			CAMEL_STORE_FOLDER_INFO_RECURSIVE |
+			CAMEL_STORE_FOLDER_INFO_SUBSCRIBED,
+			G_PRIORITY_DEFAULT, ud->cancellable,
+			(GAsyncReadyCallback) update_folders, ud);
 	} else {
-		/* the store vanished, that means we were probably cancelled, or at any rate,
-		   need to clean ourselves up */
+		/* The store vanished, that means we were probably cancelled,
+		 * or at any rate, need to clean ourselves up. */
+		if (ud->cancellable != NULL)
+			g_object_unref (ud->cancellable);
 		g_free (ud);
 	}
 
@@ -875,33 +884,35 @@ store_go_online_cb (CamelStore *store,
 }
 
 struct _find_info {
-	const gchar *uri;
+	const gchar *folder_uri;
 	struct _folder_info *fi;
-	CamelURL *url;
 };
 
-/* look up on each storeinfo using proper hash function for that stores uri's */
 static void
 storeinfo_find_folder_info (CamelStore *store,
                             struct _store_info *si,
                             struct _find_info *fi)
 {
-	if (fi->fi == NULL) {
-		if (((CamelService *)store)->provider->url_equal (
-			fi->url, ((CamelService *)store)->url)) {
-			gchar *path = fi->url->fragment?fi->url->fragment:fi->url->path;
+	gchar *folder_name;
+	gboolean success;
 
-			if (path[0] == '/')
-				path++;
-			fi->fi = g_hash_table_lookup (si->folders, path);
-		}
+	if (fi->fi != NULL)
+		return;
+
+	success = e_mail_folder_uri_parse (
+		camel_service_get_session (CAMEL_SERVICE (store)),
+		fi->folder_uri, NULL, &folder_name, NULL);
+
+	if (success) {
+		fi->fi = g_hash_table_lookup (si->folders, folder_name);
+		g_free (folder_name);
 	}
 }
 
 static void
 mail_folder_cache_finalize (GObject *object)
 {
-	MailFolderCache *cache = (MailFolderCache*) object;
+	MailFolderCache *cache = (MailFolderCache *) object;
 
 	g_hash_table_destroy (cache->priv->stores);
 	g_mutex_free (cache->priv->stores_mutex);
@@ -933,73 +944,78 @@ mail_folder_cache_class_init (MailFolderCacheClass *class)
 	/**
 	 * MailFolderCache::folder-available
 	 * @store: the #CamelStore containing the folder
-	 * @uri: the uri of the folder
+	 * @folder_name: the name of the folder
 	 *
 	 * Emitted when a folder becomes available
 	 **/
-	signals[FOLDER_AVAILABLE] =
-		g_signal_new ("folder-available",
-			      G_OBJECT_CLASS_TYPE (object_class),
-			      G_SIGNAL_RUN_FIRST,
-			      0, /* struct offset */
-			      NULL, NULL, /* accumulator */
-			      e_marshal_VOID__OBJECT_STRING,
-			      G_TYPE_NONE, 2,
-			      CAMEL_TYPE_OBJECT, G_TYPE_STRING);
+	signals[FOLDER_AVAILABLE] = g_signal_new (
+		"folder-available",
+		G_OBJECT_CLASS_TYPE (object_class),
+		G_SIGNAL_RUN_FIRST,
+		0, /* struct offset */
+		NULL, NULL, /* accumulator */
+		e_marshal_VOID__OBJECT_STRING,
+		G_TYPE_NONE, 2,
+		CAMEL_TYPE_STORE,
+		G_TYPE_STRING);
 
 	/**
 	 * MailFolderCache::folder-unavailable
 	 * @store: the #CamelStore containing the folder
-	 * @uri: the uri of the folder
+	 * @folder_name: the name of the folder
 	 *
 	 * Emitted when a folder becomes unavailable.  This represents a
 	 * transient condition.  See MailFolderCache::folder-deleted to be
 	 * notified when a folder is permanently removed.
 	 **/
-	signals[FOLDER_UNAVAILABLE] =
-		g_signal_new ("folder-unavailable",
-			      G_OBJECT_CLASS_TYPE (object_class),
-			      G_SIGNAL_RUN_FIRST,
-			      0, /* struct offset */
-			      NULL, NULL, /* accumulator */
-			      e_marshal_VOID__OBJECT_STRING,
-			      G_TYPE_NONE, 2,
-			      CAMEL_TYPE_OBJECT, G_TYPE_STRING);
+	signals[FOLDER_UNAVAILABLE] = g_signal_new (
+		"folder-unavailable",
+		G_OBJECT_CLASS_TYPE (object_class),
+		G_SIGNAL_RUN_FIRST,
+		0, /* struct offset */
+		NULL, NULL, /* accumulator */
+		e_marshal_VOID__OBJECT_STRING,
+		G_TYPE_NONE, 2,
+		CAMEL_TYPE_STORE,
+		G_TYPE_STRING);
 
 	/**
 	 * MailFolderCache::folder-deleted
 	 * @store: the #CamelStore containing the folder
-	 * @uri: the uri of the folder
+	 * @folder_name: the name of the folder
 	 *
 	 * Emitted when a folder is deleted
 	 **/
-	signals[FOLDER_DELETED] =
-		g_signal_new ("folder-deleted",
-			      G_OBJECT_CLASS_TYPE (object_class),
-			      G_SIGNAL_RUN_FIRST,
-			      0, /* struct offset */
-			      NULL, NULL, /* accumulator */
-			      e_marshal_VOID__OBJECT_STRING,
-			      G_TYPE_NONE, 2,
-			      CAMEL_TYPE_OBJECT, G_TYPE_STRING);
+	signals[FOLDER_DELETED] = g_signal_new (
+		"folder-deleted",
+		G_OBJECT_CLASS_TYPE (object_class),
+		G_SIGNAL_RUN_FIRST,
+		0, /* struct offset */
+		NULL, NULL, /* accumulator */
+		e_marshal_VOID__OBJECT_STRING,
+		G_TYPE_NONE, 2,
+		CAMEL_TYPE_STORE,
+		G_TYPE_STRING);
 
 	/**
 	 * MailFolderCache::folder-renamed
 	 * @store: the #CamelStore containing the folder
-	 * @old_uri: the old uri of the folder
-	 * @new_uri: the new uri of the folder
+	 * @old_folder_name: the old name of the folder
+	 * @new_folder_name: the new name of the folder
 	 *
 	 * Emitted when a folder is renamed
 	 **/
-	signals[FOLDER_RENAMED] =
-		g_signal_new ("folder-renamed",
-			      G_OBJECT_CLASS_TYPE (object_class),
-			      G_SIGNAL_RUN_FIRST,
-			      0, /* struct offset */
-			      NULL, NULL, /* accumulator */
-			      e_marshal_VOID__OBJECT_STRING_STRING,
-			      G_TYPE_NONE, 3,
-			      CAMEL_TYPE_OBJECT, G_TYPE_STRING, G_TYPE_STRING);
+	signals[FOLDER_RENAMED] = g_signal_new (
+		"folder-renamed",
+		G_OBJECT_CLASS_TYPE (object_class),
+		G_SIGNAL_RUN_FIRST,
+		0, /* struct offset */
+		NULL, NULL, /* accumulator */
+		e_marshal_VOID__OBJECT_STRING_STRING,
+		G_TYPE_NONE, 3,
+		CAMEL_TYPE_STORE,
+		G_TYPE_STRING,
+		G_TYPE_STRING);
 
 	/**
 	 * MailFolderCache::folder-unread-updated
@@ -1022,26 +1038,29 @@ mail_folder_cache_class_init (MailFolderCacheClass *class)
 	/**
 	 * MailFolderCache::folder-changed
 	 * @store: the #CamelStore containing the folder
-	 * @folder_uri: the uri of the folder
 	 * @folder_fullname: the full name of the folder
 	 * @new_messages: the number of new messages for the folder
 	 * @msg_uid: uid of the new message, or NULL
 	 * @msg_sender: sender of the new message, or NULL
 	 * @msg_subject: subject of the new message, or NULL
 	 *
-	 * Emitted when a folder has changed.  If @new_messages is not exactly 1,
-	 * @msgt_uid, @msg_sender, and @msg_subject will be NULL.
+	 * Emitted when a folder has changed.  If @new_messages is not
+	 * exactly 1, @msg_uid, @msg_sender, and @msg_subject will be NULL.
 	 **/
-	signals[FOLDER_CHANGED] =
-		g_signal_new ("folder-changed",
-			      G_OBJECT_CLASS_TYPE (object_class),
-			      G_SIGNAL_RUN_FIRST,
-			      0, /* struct offset */
-			      NULL, NULL, /* accumulator */
-			      e_marshal_VOID__OBJECT_STRING_STRING_INT_STRING_STRING_STRING,
-			      G_TYPE_NONE, 7,
-			      CAMEL_TYPE_OBJECT, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_INT,
-			      G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING);
+	signals[FOLDER_CHANGED] = g_signal_new (
+		"folder-changed",
+		G_OBJECT_CLASS_TYPE (object_class),
+		G_SIGNAL_RUN_FIRST,
+		0, /* struct offset */
+		NULL, NULL, /* accumulator */
+		e_marshal_VOID__OBJECT_STRING_INT_STRING_STRING_STRING,
+		G_TYPE_NONE, 6,
+		CAMEL_TYPE_STORE,
+		G_TYPE_STRING,
+		G_TYPE_INT,
+		G_TYPE_STRING,
+		G_TYPE_STRING,
+		G_TYPE_STRING);
 }
 
 static void
@@ -1101,21 +1120,20 @@ mail_folder_cache_note_store (MailFolderCache *self,
 	if (si == NULL) {
 		si = g_malloc0 (sizeof (*si));
 		si->folders = g_hash_table_new (g_str_hash, g_str_equal);
-		si->folders_uri = g_hash_table_new (
-			CAMEL_STORE_GET_CLASS (store)->hash_folder_name,
-			CAMEL_STORE_GET_CLASS (store)->compare_folder_name);
 		si->store = g_object_ref (store);
 		g_hash_table_insert (self->priv->stores, store, si);
 		g_queue_init (&si->folderinfo_updates);
 		hook = TRUE;
 	}
 
-	ud = g_malloc (sizeof (*ud));
+	ud = g_malloc0 (sizeof (*ud));
 	ud->done = done;
 	ud->data = data;
-	ud->cancel = 0;
 	ud->cache = self;
 
+	if (G_IS_CANCELLABLE (cancellable))
+		ud->cancellable = g_object_ref (cancellable);
+
 	/* We might get a race when setting up a store, such that it is
 	 * still left in offline mode, after we've gone online.  This
 	 * catches and fixes it up when the shell opens us. */
@@ -1141,8 +1159,13 @@ mail_folder_cache_note_store (MailFolderCache *self,
 		}
 	} else {
 	normal_setup:
-		ud->id = mail_get_folderinfo (
-			store, cancellable, update_folders, ud);
+		camel_store_get_folder_info (
+			store, NULL,
+			CAMEL_STORE_FOLDER_INFO_FAST |
+			CAMEL_STORE_FOLDER_INFO_RECURSIVE |
+			CAMEL_STORE_FOLDER_INFO_SUBSCRIBED,
+			G_PRIORITY_DEFAULT, cancellable,
+			(GAsyncReadyCallback) update_folders, ud);
 	}
 
 	g_queue_push_tail (&si->folderinfo_updates, ud);
@@ -1164,6 +1187,9 @@ mail_folder_cache_note_store (MailFolderCache *self,
 		g_signal_connect (
 			store, "folder-renamed",
 			G_CALLBACK (store_folder_renamed_cb), self);
+	}
+
+	if (hook && CAMEL_IS_SUBSCRIBABLE (store)) {
 		g_signal_connect (
 			store, "folder-subscribed",
 			G_CALLBACK (store_folder_subscribed_cb), self);
@@ -1209,18 +1235,13 @@ mail_folder_cache_note_store_remove (MailFolderCache *self,
 
 		while (link != NULL) {
 			struct _update_data *ud = link->data;
-
-			d(printf("Cancelling outstanding folderinfo update %d\n", ud->id));
-			mail_msg_cancel (ud->id);
-			ud->cancel = 1;
-
+			g_cancellable_cancel (ud->cancellable);
 			link = g_list_next (link);
 		}
 
 		g_object_unref (si->store);
-		g_hash_table_foreach (si->folders, (GHFunc)free_folder_info_hash, NULL);
+		g_hash_table_foreach (si->folders, (GHFunc) free_folder_info_hash, NULL);
 		g_hash_table_destroy (si->folders);
-		g_hash_table_destroy (si->folders_uri);
 		g_free (si);
 	}
 
@@ -1287,13 +1308,11 @@ mail_folder_cache_get_folder_from_uri (MailFolderCache *self,
                                        const gchar *uri,
                                        CamelFolder **folderp)
 {
-	struct _find_info fi = { uri, NULL, NULL };
+	struct _find_info fi = { uri, NULL };
 
 	if (self->priv->stores == NULL)
 		return FALSE;
 
-	fi.url = camel_url_new (uri, NULL);
-
 	g_mutex_lock (self->priv->stores_mutex);
 	g_hash_table_foreach (
 		self->priv->stores, (GHFunc)
@@ -1306,23 +1325,22 @@ mail_folder_cache_get_folder_from_uri (MailFolderCache *self,
 	}
 	g_mutex_unlock (self->priv->stores_mutex);
 
-	camel_url_free (fi.url);
-
 	return fi.fi != NULL;
 }
 
 gboolean
 mail_folder_cache_get_folder_info_flags (MailFolderCache *self,
                                          CamelFolder *folder,
-                                         gint *flags)
+                                         CamelFolderInfoFlags *flags)
 {
-	const gchar *uri = camel_folder_get_uri (folder);
-	struct _find_info fi = { uri, NULL, NULL };
+	struct _find_info fi = { NULL, NULL };
+	gchar *folder_uri;
 
 	if (self->priv->stores == NULL)
 		return FALSE;
 
-	fi.url = camel_url_new (uri, NULL);
+	folder_uri = e_mail_folder_uri_from_folder (folder);
+	fi.folder_uri = folder_uri;
 
 	g_mutex_lock (self->priv->stores_mutex);
 	g_hash_table_foreach (
@@ -1336,20 +1354,20 @@ mail_folder_cache_get_folder_info_flags (MailFolderCache *self,
 	}
 	g_mutex_unlock (self->priv->stores_mutex);
 
-	camel_url_free (fi.url);
+	g_free (folder_uri);
 
 	return fi.fi != NULL;
 }
 
 /* Returns whether folder 'folder' has children based on folder_info->child property.
-   If not found returns FALSE and sets 'found' to FALSE, if not NULL. */
+ * If not found returns FALSE and sets 'found' to FALSE, if not NULL. */
 gboolean
 mail_folder_cache_get_folder_has_children (MailFolderCache *self,
                                            CamelFolder *folder,
                                            gboolean *found)
 {
-	const gchar *uri = camel_folder_get_uri (folder);
-	struct _find_info fi = { uri, NULL, NULL };
+	struct _find_info fi = { NULL, NULL };
+	gchar *folder_uri;
 
 	g_return_val_if_fail (self != NULL, FALSE);
 	g_return_val_if_fail (folder != NULL, FALSE);
@@ -1357,7 +1375,8 @@ mail_folder_cache_get_folder_has_children (MailFolderCache *self,
 	if (self->priv->stores == NULL)
 		return FALSE;
 
-	fi.url = camel_url_new (uri, NULL);
+	folder_uri = e_mail_folder_uri_from_folder (folder);
+	fi.folder_uri = folder_uri;
 
 	g_mutex_lock (self->priv->stores_mutex);
 	g_hash_table_foreach (
@@ -1367,7 +1386,7 @@ mail_folder_cache_get_folder_has_children (MailFolderCache *self,
 		*found = fi.fi != NULL;
 	g_mutex_unlock (self->priv->stores_mutex);
 
-	camel_url_free (fi.url);
+	g_free (folder_uri);
 
 	return fi.fi != NULL && fi.fi->has_children;
 }
