@@ -155,13 +155,15 @@ typedef struct {
 static gboolean check_is_instance (icalcomponent *icalcomp);
 
 gint
-e_plugin_lib_enable (EPlugin *ep, gint enable)
+e_plugin_lib_enable (EPlugin *ep,
+                     gint enable)
 {
 	return 0;
 }
 
 static icalproperty *
-find_attendee (icalcomponent *ical_comp, const gchar *address)
+find_attendee (icalcomponent *ical_comp,
+               const gchar *address)
 {
 	icalproperty *prop;
 
@@ -194,7 +196,8 @@ find_attendee (icalcomponent *ical_comp, const gchar *address)
 }
 
 static icalproperty *
-find_attendee_if_sentby (icalcomponent *ical_comp, const gchar *address)
+find_attendee_if_sentby (icalcomponent *ical_comp,
+                         const gchar *address)
 {
 	icalproperty *prop;
 
@@ -230,7 +233,9 @@ find_attendee_if_sentby (icalcomponent *ical_comp, const gchar *address)
 }
 
 static void
-find_to_address (struct _itip_puri *pitip, icalcomponent *ical_comp, icalparameter_partstat *status)
+find_to_address (struct _itip_puri *pitip,
+                 icalcomponent *ical_comp,
+                 icalparameter_partstat *status)
 {
 	EIterator *it;
 
@@ -352,7 +357,8 @@ find_to_address (struct _itip_puri *pitip, icalcomponent *ical_comp, icalparamet
 }
 
 static void
-find_from_address (struct _itip_puri *pitip, icalcomponent *ical_comp)
+find_from_address (struct _itip_puri *pitip,
+                   icalcomponent *ical_comp)
 {
 	EIterator *it;
 	icalproperty *prop;
@@ -439,7 +445,8 @@ get_real_item (struct _itip_puri *pitip)
 }
 
 static void
-adjust_item (struct _itip_puri *pitip, ECalComponent *comp)
+adjust_item (struct _itip_puri *pitip,
+             ECalComponent *comp)
 {
 	ECalComponent *real_comp;
 
@@ -477,7 +484,9 @@ set_buttons_sensitive (struct _itip_puri *pitip)
 }
 
 static void
-add_failed_to_load_msg (ItipView *view, ESource *source, const GError *error)
+add_failed_to_load_msg (ItipView *view,
+                        ESource *source,
+                        const GError *error)
 {
 	gchar *msg;
 
@@ -486,7 +495,7 @@ add_failed_to_load_msg (ItipView *view, ESource *source, const GError *error)
 	g_return_if_fail (error != NULL);
 
 	/* Translators: The first '%s' is replaced with a calendar name,
-	   the second '%s' with an error message */
+	 * the second '%s' with an error message */
 	msg = g_strdup_printf (_("Failed to load the calendar '%s' (%s)"), e_source_peek_name (source), error->message);
 
 	itip_view_add_lower_info_item (view, ITIP_VIEW_INFO_ITEM_TYPE_WARNING, msg);
@@ -495,56 +504,66 @@ add_failed_to_load_msg (ItipView *view, ESource *source, const GError *error)
 }
 
 static void
-cal_opened_cb (GObject *source_object, GAsyncResult *result, gpointer user_data)
+cal_opened_cb (GObject *source_object,
+               GAsyncResult *result,
+               gpointer user_data)
 {
+	ESource *source = E_SOURCE (source_object);
 	struct _itip_puri *pitip = user_data;
-	ESource *source;
 	ECalClientSourceType source_type;
 	EClient *client = NULL;
 	ECalClient *cal_client;
+	const gchar *uid;
 	GError *error = NULL;
 
-	source = E_SOURCE (source_object);
+	e_client_utils_open_new_finish (source, result, &client, &error);
 
-	if (!e_client_utils_open_new_finish (source, result, &client, &error)) {
-		client = NULL;
-		if (g_error_matches (error, E_CLIENT_ERROR, E_CLIENT_ERROR_CANCELLED) ||
-		    g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED)) {
-			g_error_free (error);
-			return;
-		}
-	}
-
-	if (error) {
-		d(printf ("Failed opening itip formatter calendar '%s' during non-search opening\n", e_source_peek_name (source)));
-
-		add_failed_to_load_msg (ITIP_VIEW (pitip->view), source, error);
+	/* Ignore cancellations. */
+	if (g_error_matches (error, E_CLIENT_ERROR, E_CLIENT_ERROR_CANCELLED) ||
+	    g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED)) {
+		g_warn_if_fail (client == NULL);
+		g_error_free (error);
+		return;
 
+	} else if (error != NULL) {
+		g_warn_if_fail (client == NULL);
+		add_failed_to_load_msg (
+			ITIP_VIEW (pitip->view), source, error);
 		g_error_free (error);
 		return;
 	}
 
+	g_return_if_fail (E_IS_CAL_CLIENT (client));
+
 	cal_client = E_CAL_CLIENT (client);
 	g_return_if_fail (cal_client != NULL);
 
+	uid = e_source_peek_uid (source);
 	source_type = e_cal_client_get_source_type (cal_client);
-	g_hash_table_insert (pitip->clients[source_type], g_strdup (e_source_peek_uid (source)), cal_client);
+	g_hash_table_insert (
+		pitip->clients[source_type], g_strdup (uid), cal_client);
 
 	if (e_cal_client_check_recurrences_no_master (cal_client)) {
-		icalcomponent *icalcomp = e_cal_component_get_icalcomponent (pitip->comp);
+		icalcomponent *icalcomp;
+		gboolean show_recur_check;
 
-		if (check_is_instance (icalcomp))
-			itip_view_set_show_recur_check (ITIP_VIEW (pitip->view), TRUE);
-		else
-			itip_view_set_show_recur_check (ITIP_VIEW (pitip->view), FALSE);
+		icalcomp = e_cal_component_get_icalcomponent (pitip->comp);
+
+		show_recur_check = check_is_instance (icalcomp);
+		itip_view_set_show_recur_check (
+			ITIP_VIEW (pitip->view), show_recur_check);
 	}
 
 	if (pitip->type == E_CAL_CLIENT_SOURCE_TYPE_MEMOS) {
-		if (e_client_check_capability (E_CLIENT (client), CAL_STATIC_CAPABILITY_HAS_UNACCEPTED_MEETING))
-			itip_view_set_needs_decline (ITIP_VIEW (pitip->view), TRUE);
-		else
-			itip_view_set_needs_decline (ITIP_VIEW (pitip->view), FALSE);
-		itip_view_set_mode (ITIP_VIEW (pitip->view), ITIP_VIEW_MODE_PUBLISH);
+		gboolean needs_decline;
+
+		needs_decline = e_client_check_capability (
+			E_CLIENT (client),
+			CAL_STATIC_CAPABILITY_HAS_UNACCEPTED_MEETING);
+		itip_view_set_needs_decline (
+			ITIP_VIEW (pitip->view), needs_decline);
+		itip_view_set_mode (
+			ITIP_VIEW (pitip->view), ITIP_VIEW_MODE_PUBLISH);
 	}
 
 	pitip->current_client = cal_client;
@@ -553,7 +572,11 @@ cal_opened_cb (GObject *source_object, GAsyncResult *result, gpointer user_data)
 }
 
 static void
-start_calendar_server (struct _itip_puri *pitip, ESource *source, ECalClientSourceType type, GAsyncReadyCallback func, gpointer data)
+start_calendar_server (struct _itip_puri *pitip,
+                       ESource *source,
+                       ECalClientSourceType type,
+                       GAsyncReadyCallback func,
+                       gpointer data)
 {
 	ECalClient *client;
 
@@ -581,7 +604,9 @@ start_calendar_server (struct _itip_puri *pitip, ESource *source, ECalClientSour
 }
 
 static void
-start_calendar_server_by_uid (struct _itip_puri *pitip, const gchar *uid, ECalClientSourceType type)
+start_calendar_server_by_uid (struct _itip_puri *pitip,
+                              const gchar *uid,
+                              ECalClientSourceType type)
 {
 	gint i;
 
@@ -599,7 +624,9 @@ start_calendar_server_by_uid (struct _itip_puri *pitip, const gchar *uid, ECalCl
 }
 
 static void
-source_selected_cb (ItipView *view, ESource *source, gpointer data)
+source_selected_cb (ItipView *view,
+                    ESource *source,
+                    gpointer data)
 {
 	struct _itip_puri *pitip = data;
 
@@ -611,7 +638,8 @@ source_selected_cb (ItipView *view, ESource *source, gpointer data)
 }
 
 static void
-find_cal_update_ui (FormatItipFindData *fd, ECalClient *cal_client)
+find_cal_update_ui (FormatItipFindData *fd,
+                    ECalClient *cal_client)
 {
 	struct _itip_puri *pitip;
 	ESource *source;
@@ -697,8 +725,8 @@ decrease_find_data (FormatItipFindData *fd)
 
 		/*
 		 * Only allow replies if backend doesn't do that automatically.
-                 * Only enable it for forwarded invitiations (PUBLISH) or direct
-                 * invitiations (REQUEST), but not replies (REPLY).
+ *               * Only enable it for forwarded invitiations (PUBLISH) or direct
+ *               * invitiations (REQUEST), but not replies (REPLY).
 		 * Replies only make sense for events with an organizer.
 		 */
 		if (pitip->current_client && !e_cal_client_check_save_schedules (pitip->current_client) &&
@@ -792,7 +820,9 @@ decrease_find_data (FormatItipFindData *fd)
 }
 
 static void
-get_object_without_rid_ready_cb (GObject *source_object, GAsyncResult *result, gpointer user_data)
+get_object_without_rid_ready_cb (GObject *source_object,
+                                 GAsyncResult *result,
+                                 gpointer user_data)
 {
 	ECalClient *cal_client = E_CAL_CLIENT (source_object);
 	FormatItipFindData *fd = user_data;
@@ -803,8 +833,9 @@ get_object_without_rid_ready_cb (GObject *source_object, GAsyncResult *result, g
 		icalcomp = NULL;
 
 	if (g_error_matches (error, E_CLIENT_ERROR, E_CLIENT_ERROR_CANCELLED) ||
-	    g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED)) {
-		g_error_free (error);
+	    g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED) ||
+	    g_cancellable_is_cancelled (fd->cancellable)) {
+		g_clear_error (&error);
 		find_cal_update_ui (fd, cal_client);
 		decrease_find_data (fd);
 		return;
@@ -832,7 +863,9 @@ get_object_without_rid_ready_cb (GObject *source_object, GAsyncResult *result, g
 }
 
 static void
-get_object_with_rid_ready_cb (GObject *source_object, GAsyncResult *result, gpointer user_data)
+get_object_with_rid_ready_cb (GObject *source_object,
+                              GAsyncResult *result,
+                              gpointer user_data)
 {
 	ECalClient *cal_client = E_CAL_CLIENT (source_object);
 	FormatItipFindData *fd = user_data;
@@ -843,7 +876,8 @@ get_object_with_rid_ready_cb (GObject *source_object, GAsyncResult *result, gpoi
 		icalcomp = NULL;
 
 	if (g_error_matches (error, E_CLIENT_ERROR, E_CLIENT_ERROR_CANCELLED) ||
-	    g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED)) {
+	    g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED) ||
+	    g_cancellable_is_cancelled (fd->cancellable)) {
 		g_error_free (error);
 		find_cal_update_ui (fd, cal_client);
 		decrease_find_data (fd);
@@ -877,7 +911,9 @@ get_object_with_rid_ready_cb (GObject *source_object, GAsyncResult *result, gpoi
 }
 
 static void
-get_object_list_ready_cb (GObject *source_object, GAsyncResult *result, gpointer user_data)
+get_object_list_ready_cb (GObject *source_object,
+                          GAsyncResult *result,
+                          gpointer user_data)
 {
 	ECalClient *cal_client = E_CAL_CLIENT (source_object);
 	FormatItipFindData *fd = user_data;
@@ -887,6 +923,12 @@ get_object_list_ready_cb (GObject *source_object, GAsyncResult *result, gpointer
 	if (!e_cal_client_get_object_list_finish (cal_client, result, &objects, &error))
 		objects = NULL;
 
+	if (g_cancellable_is_cancelled (fd->cancellable)) {
+		g_clear_error (&error);
+		decrease_find_data (fd);
+		return;
+	}
+
 	if (error) {
 		if (g_error_matches (error, E_CLIENT_ERROR, E_CLIENT_ERROR_CANCELLED) ||
 		    g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED)) {
@@ -905,43 +947,56 @@ get_object_list_ready_cb (GObject *source_object, GAsyncResult *result, gpointer
 }
 
 static void
-find_cal_opened_cb (GObject *source_object, GAsyncResult *result, gpointer user_data)
+find_cal_opened_cb (GObject *source_object,
+                    GAsyncResult *result,
+                    gpointer user_data)
 {
+	ESource *source = E_SOURCE (source_object);
 	FormatItipFindData *fd = user_data;
 	struct _itip_puri *pitip = fd->puri;
-	ESource *source;
 	ECalClientSourceType source_type;
 	EClient *client = NULL;
 	ECalClient *cal_client;
+	const gchar *uid;
 	GError *error = NULL;
 
-	source = E_SOURCE (source_object);
+	e_client_utils_open_new_finish (source, result, &client, &error);
 
-	if (!e_client_utils_open_new_finish (source, result, &client, &error)) {
-		if (g_error_matches (error, E_CLIENT_ERROR, E_CLIENT_ERROR_CANCELLED) ||
-		    g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED)) {
-			g_error_free (error);
-			decrease_find_data (fd);
-			return;
-		}
+	/* Ignore cancellations. */
+	if (g_error_matches (error, E_CLIENT_ERROR, E_CLIENT_ERROR_CANCELLED) ||
+	    g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED)) {
+		g_warn_if_fail (client == NULL);
+		decrease_find_data (fd);
+		g_error_free (error);
+		return;
+	}
+
+	if (g_cancellable_is_cancelled (fd->cancellable)) {
+		g_clear_error (&error);
+		decrease_find_data (fd);
+		return;
 	}
 
 	if (error) {
 		/* FIXME Do we really want to warn here?  If we fail
 		 * to find the item, this won't be cleared but the
 		 * selector might be shown */
-		d(printf ("Failed opening itip formatter calendar '%s' during search opening... ", e_source_peek_name (source)));
-		add_failed_to_load_msg (ITIP_VIEW (pitip->view), source, error);
-
-		g_error_free (error);
+		g_warn_if_fail (client == NULL);
+		add_failed_to_load_msg (
+			ITIP_VIEW (pitip->view), source, error);
 		decrease_find_data (fd);
+		g_error_free (error);
 		return;
 	}
 
+	g_return_if_fail (E_IS_CAL_CLIENT (client));
+
 	cal_client = E_CAL_CLIENT (client);
 	source_type = e_cal_client_get_source_type (cal_client);
 
-	g_hash_table_insert (pitip->clients[source_type], g_strdup (e_source_peek_uid (source)), cal_client);
+	uid = e_source_peek_uid (source);
+	g_hash_table_insert (
+		pitip->clients[source_type], g_strdup (uid), cal_client);
 
 	/* Check for conflicts */
 	/* If the query fails, we'll just ignore it */
@@ -962,7 +1017,8 @@ find_cal_opened_cb (GObject *source_object, GAsyncResult *result, gpointer user_
 }
 
 static void
-find_server (struct _itip_puri *pitip, ECalComponent *comp)
+find_server (struct _itip_puri *pitip,
+             ECalComponent *comp)
 {
 	FormatItipFindData *fd = NULL;
 	GSList *groups, *l, *sources_conflict = NULL, *all_sources = NULL;
@@ -1074,7 +1130,9 @@ find_server (struct _itip_puri *pitip, ECalComponent *comp)
 }
 
 static gboolean
-change_status (icalcomponent *ical_comp, const gchar *address, icalparameter_partstat status)
+change_status (icalcomponent *ical_comp,
+               const gchar *address,
+               icalparameter_partstat status)
 {
 	icalproperty *prop;
 
@@ -1120,7 +1178,8 @@ change_status (icalcomponent *ical_comp, const gchar *address, icalparameter_par
 }
 
 static void
-message_foreach_part (CamelMimePart *part, GSList **part_list)
+message_foreach_part (CamelMimePart *part,
+                      GSList **part_list)
 {
 	CamelDataWrapper *containee;
 	gint parts, i;
@@ -1253,7 +1312,8 @@ get_uri_for_part (CamelMimePart *mime_part)
 }
 
 static gboolean
-update_item (struct _itip_puri *pitip, ItipViewResponse response)
+update_item (struct _itip_puri *pitip,
+             ItipViewResponse response)
 {
 	struct icaltimetype stamp;
 	icalproperty *prop;
@@ -1432,7 +1492,8 @@ update_item (struct _itip_puri *pitip, ItipViewResponse response)
 
 /* TODO These operations should be available in e-cal-component.c */
 static void
-set_attendee (ECalComponent *comp, const gchar *address)
+set_attendee (ECalComponent *comp,
+              const gchar *address)
 {
 	icalproperty *prop;
 	icalcomponent *icalcomp;
@@ -1476,7 +1537,11 @@ set_attendee (ECalComponent *comp, const gchar *address)
 }
 
 static gboolean
-send_comp_to_attendee (ECalComponentItipMethod method, ECalComponent *comp, const gchar *user, ECalClient *client, const gchar *comment)
+send_comp_to_attendee (ECalComponentItipMethod method,
+                       ECalComponent *comp,
+                       const gchar *user,
+                       ECalClient *client,
+                       const gchar *comment)
 {
 	gboolean status;
 	ECalComponent *send_comp = e_cal_component_clone (comp);
@@ -1505,7 +1570,10 @@ send_comp_to_attendee (ECalComponentItipMethod method, ECalComponent *comp, cons
 }
 
 static void
-remove_delegate (struct _itip_puri *pitip, const gchar *delegate, const gchar *delegator, ECalComponent *comp)
+remove_delegate (struct _itip_puri *pitip,
+                 const gchar *delegate,
+                 const gchar *delegator,
+                 ECalComponent *comp)
 {
 	gboolean status;
 	gchar *comment = g_strdup_printf (_("Organizer has removed the delegate %s "), itip_strip_mailto (delegate));
@@ -1524,7 +1592,8 @@ remove_delegate (struct _itip_puri *pitip, const gchar *delegate, const gchar *d
 }
 
 static void
-update_x (ECalComponent *pitip_comp, ECalComponent *comp)
+update_x (ECalComponent *pitip_comp,
+          ECalComponent *comp)
 {
 	icalcomponent *itip_icalcomp = e_cal_component_get_icalcomponent (pitip_comp);
 	icalcomponent *icalcomp = e_cal_component_get_icalcomponent (comp);
@@ -1759,7 +1828,8 @@ attachment_load_finish (EAttachment *attachment,
 }
 
 static void
-save_vcalendar_cb (GtkWidget *button, struct _itip_puri *pitip)
+save_vcalendar_cb (GtkWidget *button,
+                   struct _itip_puri *pitip)
 {
 	EAttachment *attachment;
 	EShell *shell;
@@ -1791,7 +1861,10 @@ save_vcalendar_cb (GtkWidget *button, struct _itip_puri *pitip)
 }
 
 static GtkWidget *
-set_itip_error (struct _itip_puri *pitip, GtkContainer *container, const gchar *primary, const gchar *secondary)
+set_itip_error (struct _itip_puri *pitip,
+                GtkContainer *container,
+                const gchar *primary,
+                const gchar *secondary)
 {
 	GtkWidget *vbox, *label;
 	gchar *message;
@@ -1818,7 +1891,9 @@ set_itip_error (struct _itip_puri *pitip, GtkContainer *container, const gchar *
 }
 
 static gboolean
-extract_itip_data (struct _itip_puri *pitip, GtkContainer *container, gboolean *have_alarms)
+extract_itip_data (struct _itip_puri *pitip,
+                   GtkContainer *container,
+                   gboolean *have_alarms)
 {
 	EShell *shell;
 	EShellSettings *shell_settings;
@@ -2089,7 +2164,8 @@ struct _opencal_msg {
 };
 
 static gchar *
-open_calendar__desc (struct _opencal_msg *m, gint complete)
+open_calendar__desc (struct _opencal_msg *m,
+                     gint complete)
 {
 	return g_strdup (_("Opening calendar"));
 }
@@ -2129,7 +2205,7 @@ idle_open_cb (gpointer data)
 	start = isodate_from_time_t (pitip->start_time);
 	end = isodate_from_time_t (pitip->end_time);
 	m = mail_msg_new (&open_calendar_info);
-	m->command = g_strdup_printf ("evolution \"calendar://?startdate=%s&enddate=%s\"", start, end);
+	m->command = g_strdup_printf ("evolution \"calendar:///?startdate=%s&enddate=%s\"", start, end);
 	mail_msg_slow_ordered_push (m);
 
 	g_free (start);
@@ -2139,7 +2215,9 @@ idle_open_cb (gpointer data)
 }
 
 static void
-view_response_cb (GtkWidget *widget, ItipViewResponse response, gpointer data)
+view_response_cb (GtkWidget *widget,
+                  ItipViewResponse response,
+                  gpointer data)
 {
 	struct _itip_puri *pitip = data;
 	gboolean status = FALSE, delete_invitation_from_cache = FALSE;
@@ -2432,7 +2510,9 @@ in_proper_folder (CamelFolder *folder)
 }
 
 static gboolean
-format_itip_object (EMFormatHTML *efh, GtkHTMLEmbedded *eb, EMFormatHTMLPObject *pobject)
+format_itip_object (EMFormatHTML *efh,
+                    GtkHTMLEmbedded *eb,
+                    EMFormatHTMLPObject *pobject)
 {
 	EShell *shell;
 	EShellSettings *shell_settings;
@@ -2475,7 +2555,7 @@ format_itip_object (EMFormatHTML *efh, GtkHTMLEmbedded *eb, EMFormatHTMLPObject
 	gtk_container_add (GTK_CONTAINER (eb), info->view);
 	gtk_widget_show (info->view);
 
-	response_enabled = in_proper_folder (((EMFormat*) efh)->folder);
+	response_enabled = in_proper_folder (((EMFormat *) efh)->folder);
 
 	if (!response_enabled) {
 		itip_view_set_mode (ITIP_VIEW (info->view), ITIP_VIEW_MODE_HIDE_ALL);
@@ -2705,7 +2785,7 @@ format_itip_object (EMFormatHTML *efh, GtkHTMLEmbedded *eb, EMFormatHTMLPObject
 
 		if (datetime.value->is_date) {
 			/* RFC says the DTEND is not inclusive, thus subtract one day
-			   if we have a date */
+			 * if we have a date */
 
 			icaltime_adjust (datetime.value, -1, 0, 0, 0);
 		}
@@ -2756,7 +2836,7 @@ format_itip_object (EMFormatHTML *efh, GtkHTMLEmbedded *eb, EMFormatHTMLPObject
 static void
 puri_free (EMFormatPURI *puri)
 {
-	struct _itip_puri *pitip = (struct _itip_puri*) puri;
+	struct _itip_puri *pitip = (struct _itip_puri *) puri;
 	gint i;
 
 	g_cancellable_cancel (pitip->cancellable);
@@ -2811,7 +2891,8 @@ puri_free (EMFormatPURI *puri)
 }
 
 void
-format_itip (EPlugin *ep, EMFormatHookTarget *target)
+format_itip (EPlugin *ep,
+             EMFormatHookTarget *target)
 {
 	GConfClient *gconf;
 	gchar *classid;
@@ -2819,6 +2900,7 @@ format_itip (EPlugin *ep, EMFormatHookTarget *target)
 	CamelDataWrapper *content;
 	CamelStream *stream;
 	GByteArray *byte_array;
+	gchar *string;
 
 	classid = g_strdup_printf("itip:///%s", ((EMFormat *) target->format)->part_id->str);
 
@@ -2859,15 +2941,20 @@ format_itip (EPlugin *ep, EMFormatHookTarget *target)
 
 	g_object_unref (stream);
 
-	camel_stream_printf (target->stream, "<table border=0 width=\"100%%\" cellpadding=3><tr>");
-	camel_stream_printf (target->stream, "<td valign=top><object classid=\"%s\"></object></td><td width=100%% valign=top>", classid);
-	camel_stream_printf (target->stream, "</td></tr></table>");
+	string = g_strdup_printf (
+		"<table border=0 width=\"100%%\" cellpadding=3><tr>"
+		"<td valign=top><object classid=\"%s\"></object></td>"
+		"<td width=100%% valign=top></td></tr></table>",
+		classid);
+	camel_stream_write_string (target->stream, string, NULL, NULL);
+	g_free (string);
 
 	g_free (classid);
 }
 
 static void
-delete_toggled_cb (GtkWidget *widget, gpointer data)
+delete_toggled_cb (GtkWidget *widget,
+                   gpointer data)
 {
 	EMConfigTargetPrefs *target = data;
 
@@ -2875,7 +2962,8 @@ delete_toggled_cb (GtkWidget *widget, gpointer data)
 }
 
 static void
-initialize_selection (ESourceSelector *selector, ESourceList *source_list)
+initialize_selection (ESourceSelector *selector,
+                      ESourceList *source_list)
 {
 	GSList *groups;
 
@@ -2892,7 +2980,8 @@ initialize_selection (ESourceSelector *selector, ESourceList *source_list)
 }
 
 static void
-source_selection_changed (ESourceSelector *selector, gpointer data)
+source_selection_changed (ESourceSelector *selector,
+                          gpointer data)
 {
 	ESourceList *source_list = data;
 	GSList *selection;
@@ -2911,7 +3000,7 @@ source_selection_changed (ESourceSelector *selector, gpointer data)
 	}
 
 	/* then we loop over the selector's selection, setting the
-	   property on those sources */
+	 * property on those sources */
 	selection = e_source_selector_get_selection (selector);
 	for (l = selection; l; l = l->next) {
 		e_source_set_property (E_SOURCE (l->data), "conflict", "true");
@@ -2923,7 +3012,8 @@ source_selection_changed (ESourceSelector *selector, gpointer data)
 }
 
 GtkWidget *
-itip_formatter_page_factory (EPlugin *ep, EConfigHookItemFactoryData *hook_data)
+itip_formatter_page_factory (EPlugin *ep,
+                             EConfigHookItemFactoryData *hook_data)
 {
 	EMConfigTargetPrefs *target = (EMConfigTargetPrefs *) hook_data->config->target;
 	GtkWidget *page;
@@ -2943,7 +3033,7 @@ itip_formatter_page_factory (EPlugin *ep, EConfigHookItemFactoryData *hook_data)
 	/* Create a new notebook page */
 	page = gtk_vbox_new (FALSE, 0);
 	gtk_container_set_border_width (GTK_CONTAINER (page), 12);
-	tab_label = gtk_label_new (_("Calendar and Tasks"));
+	tab_label = gtk_label_new (_("Meeting Invitations"));
 	gtk_notebook_append_page (GTK_NOTEBOOK (hook_data->parent), page, tab_label);
 
 	/* Frame */
