@@ -41,8 +41,9 @@
 
 #include "format-handler.h"
 
-static void
-add_string_to_rdf (xmlNodePtr node, const gchar *tag, const gchar *value);
+static void	add_string_to_rdf		(xmlNodePtr node,
+						 const gchar *tag,
+						 const gchar *value);
 
 /* Use { */
 
@@ -79,7 +80,8 @@ enum { /* XML helper enum */
 };
 
 static void
-display_error_message (GtkWidget *parent, GError *error)
+display_error_message (GtkWidget *parent,
+                       GError *error)
 {
 	GtkWidget *dialog;
 
@@ -91,7 +93,10 @@ display_error_message (GtkWidget *parent, GError *error)
 
 /* Some helpers for the xml stuff */
 static void
-add_list_to_rdf (xmlNodePtr node, const gchar *tag, GSList *list_in, gint type)
+add_list_to_rdf (xmlNodePtr node,
+                 const gchar *tag,
+                 GSList *list_in,
+                 gint type)
 {
 	if (list_in) {
 		GSList *list = list_in;
@@ -101,10 +106,10 @@ add_list_to_rdf (xmlNodePtr node, const gchar *tag, GSList *list_in, gint type)
 
 			switch (type) {
 			case ECALCOMPONENTATTENDEE:
-				str = ((ECalComponentAttendee*) list->data)->value;
+				str = ((ECalComponentAttendee *) list->data)->value;
 				break;
 			case ECALCOMPONENTTEXT:
-				str = ((ECalComponentText*) list->data)->value;
+				str = ((ECalComponentText *) list->data)->value;
 				break;
 			case CONSTCHAR:
 			default:
@@ -120,7 +125,9 @@ add_list_to_rdf (xmlNodePtr node, const gchar *tag, GSList *list_in, gint type)
 }
 
 static void
-add_nummeric_to_rdf (xmlNodePtr node, const gchar *tag, gint *nummeric)
+add_nummeric_to_rdf (xmlNodePtr node,
+                     const gchar *tag,
+                     gint *nummeric)
 {
 	if (nummeric) {
 		gchar *value = g_strdup_printf ("%d", *nummeric);
@@ -131,7 +138,9 @@ add_nummeric_to_rdf (xmlNodePtr node, const gchar *tag, gint *nummeric)
 }
 
 static void
-add_time_to_rdf (xmlNodePtr node, const gchar *tag, icaltimetype *time)
+add_time_to_rdf (xmlNodePtr node,
+                 const gchar *tag,
+                 icaltimetype *time)
 {
 	if (time) {
 		xmlNodePtr cur_node = NULL;
@@ -159,7 +168,9 @@ add_time_to_rdf (xmlNodePtr node, const gchar *tag, icaltimetype *time)
 }
 
 static void
-add_string_to_rdf (xmlNodePtr node, const gchar *tag, const gchar *value)
+add_string_to_rdf (xmlNodePtr node,
+                   const gchar *tag,
+                   const gchar *value)
 {
 	if (value) {
 		xmlNodePtr cur_node = NULL;
@@ -169,7 +180,10 @@ add_string_to_rdf (xmlNodePtr node, const gchar *tag, const gchar *value)
 }
 
 static void
-do_save_calendar_rdf (FormatHandler *handler, ESourceSelector *selector, ECalClientSourceType type, gchar *dest_uri)
+do_save_calendar_rdf (FormatHandler *handler,
+                      ESourceSelector *selector,
+                      ECalClientSourceType type,
+                      gchar *dest_uri)
 {
 
 	/*
@@ -211,7 +225,7 @@ do_save_calendar_rdf (FormatHandler *handler, ESourceSelector *selector, ECalCli
 	if (stream && e_cal_client_get_object_list_as_comps_sync (source_client, "#t", &objects, NULL, NULL)) {
 		GSList *iter;
 
-		xmlBufferPtr buffer=xmlBufferCreate ();
+		xmlBufferPtr buffer = xmlBufferCreate ();
 		xmlDocPtr doc = xmlNewDoc((xmlChar *) "1.0");
 		xmlNodePtr fnode;
 
@@ -245,7 +259,7 @@ do_save_calendar_rdf (FormatHandler *handler, ESourceSelector *selector, ECalCli
 		xmlNewChild (fnode, NULL, (const guchar *)"version", (const guchar *)"2.0");
 
 		for (iter = objects; iter; iter = iter->next) {
-			ECalComponent *comp = objects->data;
+			ECalComponent *comp = iter->data;
 			const gchar *temp_constchar;
 			gchar *tmp_str = NULL;
 			GSList *temp_list;
@@ -372,7 +386,7 @@ FormatHandler *rdf_format_handler_new (void)
 	FormatHandler *handler = g_new (FormatHandler, 1);
 
 	handler->isdefault = FALSE;
-	handler->combo_label = _("RDF format (.rdf)");
+	handler->combo_label = _("RDF (.rdf)");
 	handler->filename_ext = ".rdf";
 	handler->options_widget = NULL;
 	handler->save = do_save_calendar_rdf;
