@@ -20,7 +20,9 @@
  *
  */
 
+#ifdef HAVE_CONFIG_H
 #include <config.h>
+#endif
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -301,13 +303,15 @@ e_tree_state_change (ETree *et)
 }
 
 static void
-change_trigger (GObject *object, ETree *et)
+change_trigger (GObject *object,
+                ETree *et)
 {
 	e_tree_state_change (et);
 }
 
 static void
-search_col_change_trigger (GObject *object, ETree *et)
+search_col_change_trigger (GObject *object,
+                           ETree *et)
 {
 	clear_current_search_col (et);
 	e_tree_state_change (et);
@@ -341,7 +345,8 @@ disconnect_header (ETree *e_tree)
 }
 
 static void
-connect_header (ETree *e_tree, ETableState *state)
+connect_header (ETree *e_tree,
+                ETableState *state)
 {
 	GValue *val = g_new0 (GValue, 1);
 
@@ -487,7 +492,9 @@ typedef struct {
 } SearchSearchStruct;
 
 static gboolean
-search_search_callback (ETreeModel *model, ETreePath path, gpointer data)
+search_search_callback (ETreeModel *model,
+                        ETreePath path,
+                        gpointer data)
 {
 	SearchSearchStruct *cb_data = data;
 	gconstpointer value;
@@ -559,7 +566,8 @@ et_search_search (ETableSearch *search,
 }
 
 static void
-et_search_accept (ETableSearch *search, ETree *et)
+et_search_accept (ETableSearch *search,
+                  ETree *et)
 {
 	ETableCol *col = current_search_col (et);
 	gint cursor;
@@ -607,12 +615,13 @@ e_tree_init (ETree *e_tree)
 
 	e_tree->priv->search = e_table_search_new ();
 
-	e_tree->priv->search_search_id =
-		g_signal_connect (G_OBJECT (e_tree->priv->search), "search",
-				 G_CALLBACK (et_search_search), e_tree);
-	e_tree->priv->search_accept_id =
-		g_signal_connect (G_OBJECT (e_tree->priv->search), "accept",
-				 G_CALLBACK (et_search_accept), e_tree);
+	e_tree->priv->search_search_id = g_signal_connect (
+		e_tree->priv->search, "search",
+		G_CALLBACK (et_search_search), e_tree);
+
+	e_tree->priv->search_accept_id = g_signal_connect (
+		e_tree->priv->search, "accept",
+		G_CALLBACK (et_search_accept), e_tree);
 
 	e_tree->priv->always_search = g_getenv ("GAL_ALWAYS_SEARCH") ? TRUE : FALSE;
 }
@@ -630,7 +639,8 @@ et_grab_focus (GtkWidget *widget)
 
 /* Focus handler for the ETree */
 static gint
-et_focus (GtkWidget *container, GtkDirectionType direction)
+et_focus (GtkWidget *container,
+          GtkDirectionType direction)
 {
 	ETree *e_tree;
 
@@ -668,7 +678,9 @@ set_header_canvas_width (ETree *e_tree)
 }
 
 static void
-header_canvas_size_allocate (GtkWidget *widget, GtkAllocation *alloc, ETree *e_tree)
+header_canvas_size_allocate (GtkWidget *widget,
+                             GtkAllocation *alloc,
+                             ETree *e_tree)
 {
 	GtkAllocation allocation;
 
@@ -678,9 +690,9 @@ header_canvas_size_allocate (GtkWidget *widget, GtkAllocation *alloc, ETree *e_t
 	gtk_widget_get_allocation (widget, &allocation);
 
 	/* When the header item is created ->height == 0,
-	   as the font is only created when everything is realized.
-	   So we set the usize here as well, so that the size of the
-	   header is correct */
+	 * as the font is only created when everything is realized.
+	 * So we set the usize here as well, so that the size of the
+	 * header is correct */
 	if (allocation.height != E_TABLE_HEADER_ITEM (e_tree->priv->header_item)->height)
 		gtk_widget_set_size_request (
 			widget, -1,
@@ -775,8 +787,8 @@ tree_canvas_reflow_idle (ETree *e_tree)
 		e_tree->priv->item,
 		"height", &height, "width", &width, NULL);
 
-	height = MAX ((gint)height, allocation.height);
-	width = MAX ((gint)width, allocation.width);
+	height = MAX ((gint) height, allocation.height);
+	width = MAX ((gint) width, allocation.width);
 
 	/* I have no idea why this needs to be -1, but it works. */
 	gnome_canvas_get_scroll_region (
@@ -802,8 +814,9 @@ tree_canvas_reflow_idle (ETree *e_tree)
 }
 
 static void
-tree_canvas_size_allocate (GtkWidget *widget, GtkAllocation *alloc,
-			    ETree *e_tree)
+tree_canvas_size_allocate (GtkWidget *widget,
+                           GtkAllocation *alloc,
+                           ETree *e_tree)
 {
 	gdouble width;
 	gdouble height;
@@ -815,7 +828,7 @@ tree_canvas_size_allocate (GtkWidget *widget, GtkAllocation *alloc,
 	g_object_get (e_tree->priv->item,
 		      "height", &height,
 		      NULL);
-	height = MAX ((gint)height, alloc->height);
+	height = MAX ((gint) height, alloc->height);
 
 	g_object_set (e_tree->priv->item,
 		      "width", width,
@@ -829,7 +842,8 @@ tree_canvas_size_allocate (GtkWidget *widget, GtkAllocation *alloc,
 }
 
 static void
-tree_canvas_reflow (GnomeCanvas *canvas, ETree *e_tree)
+tree_canvas_reflow (GnomeCanvas *canvas,
+                    ETree *e_tree)
 {
 	if (!e_tree->priv->reflow_idle_id)
 		e_tree->priv->reflow_idle_id = g_idle_add_full (
@@ -838,7 +852,9 @@ tree_canvas_reflow (GnomeCanvas *canvas, ETree *e_tree)
 }
 
 static void
-item_cursor_change (ETableItem *eti, gint row, ETree *et)
+item_cursor_change (ETableItem *eti,
+                    gint row,
+                    ETree *et)
 {
 	ETreePath path = e_tree_table_adapter_node_at_row (et->priv->etta, row);
 
@@ -846,7 +862,9 @@ item_cursor_change (ETableItem *eti, gint row, ETree *et)
 }
 
 static void
-item_cursor_activated (ETableItem *eti, gint row, ETree *et)
+item_cursor_activated (ETableItem *eti,
+                       gint row,
+                       ETree *et)
 {
 	ETreePath path = e_tree_table_adapter_node_at_row (et->priv->etta, row);
 
@@ -854,7 +872,11 @@ item_cursor_activated (ETableItem *eti, gint row, ETree *et)
 }
 
 static void
-item_double_click (ETableItem *eti, gint row, gint col, GdkEvent *event, ETree *et)
+item_double_click (ETableItem *eti,
+                   gint row,
+                   gint col,
+                   GdkEvent *event,
+                   ETree *et)
 {
 	ETreePath path = e_tree_table_adapter_node_at_row (et->priv->etta, row);
 
@@ -862,7 +884,11 @@ item_double_click (ETableItem *eti, gint row, gint col, GdkEvent *event, ETree *
 }
 
 static gboolean
-item_right_click (ETableItem *eti, gint row, gint col, GdkEvent *event, ETree *et)
+item_right_click (ETableItem *eti,
+                  gint row,
+                  gint col,
+                  GdkEvent *event,
+                  ETree *et)
 {
 	ETreePath path = e_tree_table_adapter_node_at_row (et->priv->etta, row);
 	gboolean return_val = 0;
@@ -875,7 +901,11 @@ item_right_click (ETableItem *eti, gint row, gint col, GdkEvent *event, ETree *e
 }
 
 static gboolean
-item_click (ETableItem *eti, gint row, gint col, GdkEvent *event, ETree *et)
+item_click (ETableItem *eti,
+            gint row,
+            gint col,
+            GdkEvent *event,
+            ETree *et)
 {
 	gboolean return_val = 0;
 	ETreePath path = e_tree_table_adapter_node_at_row (et->priv->etta, row);
@@ -887,7 +917,11 @@ item_click (ETableItem *eti, gint row, gint col, GdkEvent *event, ETree *et)
 }
 
 static gint
-item_key_press (ETableItem *eti, gint row, gint col, GdkEvent *event, ETree *et)
+item_key_press (ETableItem *eti,
+                gint row,
+                gint col,
+                GdkEvent *event,
+                ETree *et)
 {
 	gint return_val = 0;
 	GdkEventKey *key = (GdkEventKey *) event;
@@ -998,7 +1032,11 @@ item_key_press (ETableItem *eti, gint row, gint col, GdkEvent *event, ETree *et)
 }
 
 static gint
-item_start_drag (ETableItem *eti, gint row, gint col, GdkEvent *event, ETree *et)
+item_start_drag (ETableItem *eti,
+                 gint row,
+                 gint col,
+                 GdkEvent *event,
+                 ETree *et)
 {
 	ETreePath path;
 	gint return_val = 0;
@@ -1013,7 +1051,8 @@ item_start_drag (ETableItem *eti, gint row, gint col, GdkEvent *event, ETree *et
 }
 
 static void
-et_selection_model_selection_changed (ETableSelectionModel *etsm, ETree *et)
+et_selection_model_selection_changed (ETableSelectionModel *etsm,
+                                      ETree *et)
 {
 	g_signal_emit (et, et_signals[SELECTION_CHANGE], 0);
 }
@@ -1062,7 +1101,8 @@ et_build_item (ETree *et)
 }
 
 static void
-et_canvas_style_set (GtkWidget *widget, GtkStyle *prev_style)
+et_canvas_style_set (GtkWidget *widget,
+                     GtkStyle *prev_style)
 {
 	GtkStyle *style;
 
@@ -1075,7 +1115,9 @@ et_canvas_style_set (GtkWidget *widget, GtkStyle *prev_style)
 }
 
 static gboolean
-white_item_event (GnomeCanvasItem *white_item, GdkEvent *event, ETree *e_tree)
+white_item_event (GnomeCanvasItem *white_item,
+                  GdkEvent *event,
+                  ETree *e_tree)
 {
 	gboolean return_val = 0;
 	g_signal_emit (e_tree,
@@ -1085,7 +1127,9 @@ white_item_event (GnomeCanvasItem *white_item, GdkEvent *event, ETree *e_tree)
 }
 
 static gint
-et_canvas_root_event (GnomeCanvasItem *root, GdkEvent *event, ETree *e_tree)
+et_canvas_root_event (GnomeCanvasItem *root,
+                      GdkEvent *event,
+                      ETree *e_tree)
 {
 	switch (event->type) {
 	case GDK_BUTTON_PRESS:
@@ -1112,8 +1156,10 @@ et_canvas_root_event (GnomeCanvasItem *root, GdkEvent *event, ETree *e_tree)
 /* Handler for focus events in the table_canvas; we have to repaint ourselves
  * and give the focus to some ETableItem.
  */
-static gint
-table_canvas_focus_event_cb (GtkWidget *widget, GdkEventFocus *event, gpointer data)
+static gboolean
+table_canvas_focus_event_cb (GtkWidget *widget,
+                             GdkEventFocus *event,
+                             gpointer data)
 {
 	GnomeCanvas *canvas;
 	ETree *tree;
@@ -1211,7 +1257,8 @@ e_tree_setup_table (ETree *e_tree)
  * search column is cleared.
  */
 void
-e_tree_set_search_column (ETree *e_tree, gint  col)
+e_tree_set_search_column (ETree *e_tree,
+                          gint col)
 {
 	if (col == -1) {
 		clear_current_search_col (e_tree);
@@ -1224,7 +1271,8 @@ e_tree_set_search_column (ETree *e_tree, gint  col)
 }
 
 void
-e_tree_set_state_object (ETree *e_tree, ETableState *state)
+e_tree_set_state_object (ETree *e_tree,
+                         ETableState *state)
 {
 	GValue *val;
 	GtkAllocation allocation;
@@ -1254,7 +1302,8 @@ e_tree_set_state_object (ETree *e_tree, ETableState *state)
 			     NULL);
 
 	if (e_tree->priv->etta)
-		e_tree_table_adapter_set_sort_info (e_tree->priv->etta, e_tree->priv->sort_info);
+		e_tree_table_adapter_set_sort_info (
+			e_tree->priv->etta, e_tree->priv->sort_info);
 
 	e_tree_state_change (e_tree);
 }
@@ -1268,8 +1317,8 @@ e_tree_set_state_object (ETree *e_tree, ETableState *state)
  * #ETree object.
  */
 void
-e_tree_set_state (ETree      *e_tree,
-		   const gchar *state_str)
+e_tree_set_state (ETree *e_tree,
+                  const gchar *state_str)
 {
 	ETableState *state;
 
@@ -1295,8 +1344,8 @@ e_tree_set_state (ETree      *e_tree,
  * @e_tree object.
  */
 void
-e_tree_load_state (ETree      *e_tree,
-		    const gchar *filename)
+e_tree_load_state (ETree *e_tree,
+                   const gchar *filename)
 {
 	ETableState *state;
 
@@ -1385,8 +1434,8 @@ e_tree_get_state (ETree *e_tree)
  * @filename.
  **/
 void
-e_tree_save_state (ETree      *e_tree,
-		   const gchar *filename)
+e_tree_save_state (ETree *e_tree,
+                   const gchar *filename)
 {
 	ETableState *state;
 
@@ -1410,26 +1459,35 @@ e_tree_get_spec (ETree *e_tree)
 }
 
 static void
-et_table_model_changed (ETableModel *model, ETree *et)
+et_table_model_changed (ETableModel *model,
+                        ETree *et)
 {
 	if (et->priv->horizontal_scrolling)
 		e_table_header_update_horizontal (et->priv->header);
 }
 
 static void
-et_table_row_changed (ETableModel *table_model, gint row, ETree *et)
+et_table_row_changed (ETableModel *table_model,
+                      gint row,
+                      ETree *et)
 {
 	et_table_model_changed (table_model, et);
 }
 
 static void
-et_table_cell_changed (ETableModel *table_model, gint view_col, gint row, ETree *et)
+et_table_cell_changed (ETableModel *table_model,
+                       gint view_col,
+                       gint row,
+                       ETree *et)
 {
 	et_table_model_changed (table_model, et);
 }
 
 static void
-et_table_rows_deleted (ETableModel *table_model, gint row, gint count, ETree *et)
+et_table_rows_deleted (ETableModel *table_model,
+                       gint row,
+                       gint count,
+                       ETree *et)
 {
 	ETreePath * node, * prev_node;
 
@@ -1438,7 +1496,7 @@ et_table_rows_deleted (ETableModel *table_model, gint row, gint count, ETree *et
 			|| row == 0)
 		return;
 
-	prev_node = e_tree_node_at_row (et, row-1);
+	prev_node = e_tree_node_at_row (et, row - 1);
 	node = e_tree_get_cursor (et);
 
 	/* Check if the cursor is a child of the node directly before the
@@ -1476,8 +1534,11 @@ et_connect_to_etta (ETree *et)
 }
 
 static gboolean
-et_real_construct (ETree *e_tree, ETreeModel *etm, ETableExtras *ete,
-		   ETableSpecification *specification, ETableState *state)
+et_real_construct (ETree *e_tree,
+                   ETreeModel *etm,
+                   ETableExtras *ete,
+                   ETableSpecification *specification,
+                   ETableState *state)
 {
 	GtkAdjustment *adjustment;
 	GtkScrollable *scrollable;
@@ -1522,9 +1583,9 @@ et_real_construct (ETree *e_tree, ETreeModel *etm, ETableExtras *ete,
 		      "cursor_mode", specification->cursor_mode,
 		      NULL);
 
-	g_signal_connect(e_tree->priv->selection, "selection_changed",
+	g_signal_connect (e_tree->priv->selection, "selection_changed",
 			 G_CALLBACK (et_selection_model_selection_changed), e_tree);
-	g_signal_connect(e_tree->priv->selection, "selection_row_changed",
+	g_signal_connect (e_tree->priv->selection, "selection_row_changed",
 			 G_CALLBACK (et_selection_model_selection_row_changed), e_tree);
 
 	if (!specification->no_headers) {
@@ -1575,8 +1636,11 @@ et_real_construct (ETree *e_tree, ETreeModel *etm, ETableExtras *ete,
  * Return value: %TRUE on success, %FALSE if an error occurred
  **/
 gboolean
-e_tree_construct (ETree *e_tree, ETreeModel *etm, ETableExtras *ete,
-		   const gchar *spec_str, const gchar *state_str)
+e_tree_construct (ETree *e_tree,
+                  ETreeModel *etm,
+                  ETableExtras *ete,
+                  const gchar *spec_str,
+                  const gchar *state_str)
 {
 	ETableSpecification *specification;
 	ETableState *state;
@@ -1613,6 +1677,7 @@ e_tree_construct (ETree *e_tree, ETreeModel *etm, ETableExtras *ete,
 	}
 
 	e_tree->priv->spec = specification;
+	e_tree->priv->spec->allow_grouping = FALSE;
 
 	g_object_unref (state);
 
@@ -1634,8 +1699,11 @@ e_tree_construct (ETree *e_tree, ETreeModel *etm, ETableExtras *ete,
  * Return value: %TRUE on success, %FALSE if an error occurred
  **/
 gboolean
-e_tree_construct_from_spec_file (ETree *e_tree, ETreeModel *etm, ETableExtras *ete,
-				  const gchar *spec_fn, const gchar *state_fn)
+e_tree_construct_from_spec_file (ETree *e_tree,
+                                 ETreeModel *etm,
+                                 ETableExtras *ete,
+                                 const gchar *spec_fn,
+                                 const gchar *state_fn)
 {
 	ETableSpecification *specification;
 	ETableState *state;
@@ -1676,6 +1744,7 @@ e_tree_construct_from_spec_file (ETree *e_tree, ETreeModel *etm, ETableExtras *e
 	}
 
 	e_tree->priv->spec = specification;
+	e_tree->priv->spec->allow_grouping = FALSE;
 
 	g_object_unref (state);
 
@@ -1704,7 +1773,10 @@ e_tree_construct_from_spec_file (ETree *e_tree, ETreeModel *etm, ETableExtras *e
  * The newly created #ETree or %NULL if there's an error.
  **/
 GtkWidget *
-e_tree_new (ETreeModel *etm, ETableExtras *ete, const gchar *spec, const gchar *state)
+e_tree_new (ETreeModel *etm,
+            ETableExtras *ete,
+            const gchar *spec,
+            const gchar *state)
 {
 	ETree *e_tree;
 
@@ -1776,7 +1848,8 @@ e_tree_show_cursor_after_reflow (ETree *e_tree)
 }
 
 void
-e_tree_set_cursor (ETree *e_tree, ETreePath path)
+e_tree_set_cursor (ETree *e_tree,
+                   ETreePath path)
 {
 #ifndef E_TREE_USE_TREE_SELECTION
 	gint row;
@@ -1826,9 +1899,9 @@ e_tree_get_cursor (ETree *e_tree)
 }
 
 void
-e_tree_selected_row_foreach     (ETree *e_tree,
-				  EForeachFunc callback,
-				  gpointer closure)
+e_tree_selected_row_foreach (ETree *e_tree,
+                             EForeachFunc callback,
+                             gpointer closure)
 {
 	g_return_if_fail (e_tree != NULL);
 	g_return_if_fail (E_IS_TREE (e_tree));
@@ -1840,9 +1913,9 @@ e_tree_selected_row_foreach     (ETree *e_tree,
 
 #ifdef E_TREE_USE_TREE_SELECTION
 void
-e_tree_selected_path_foreach     (ETree *e_tree,
-				 ETreeForeachFunc callback,
-				 gpointer closure)
+e_tree_selected_path_foreach (ETree *e_tree,
+                              ETreeForeachFunc callback,
+                              gpointer closure)
 {
 	g_return_if_fail (e_tree != NULL);
 	g_return_if_fail (E_IS_TREE (e_tree));
@@ -1855,9 +1928,9 @@ e_tree_selected_path_foreach     (ETree *e_tree,
 /* Standard functions */
 static void
 et_foreach_recurse (ETreeModel *model,
-		    ETreePath path,
-		    ETreeForeachFunc callback,
-		    gpointer closure)
+                    ETreePath path,
+                    ETreeForeachFunc callback,
+                    gpointer closure)
 {
 	ETreePath child;
 
@@ -1871,8 +1944,8 @@ et_foreach_recurse (ETreeModel *model,
 
 void
 e_tree_path_foreach (ETree *e_tree,
-		     ETreeForeachFunc callback,
-		     gpointer closure)
+                     ETreeForeachFunc callback,
+                     gpointer closure)
 {
 	ETreePath root;
 
@@ -1900,13 +1973,13 @@ e_tree_get_printable (ETree *e_tree)
 
 static void
 et_get_property (GObject *object,
-		 guint prop_id,
-		 GValue *value,
-		 GParamSpec *pspec)
+                 guint property_id,
+                 GValue *value,
+                 GParamSpec *pspec)
 {
 	ETree *etree = E_TREE (object);
 
-	switch (prop_id) {
+	switch (property_id) {
 	case PROP_ETTA:
 		g_value_set_object (value, etree->priv->etta);
 		break;
@@ -1949,7 +2022,7 @@ et_get_property (GObject *object,
 			g_value_set_enum (value, 0);
 		break;
 	default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
 		break;
 	}
 }
@@ -1961,13 +2034,13 @@ typedef struct {
 
 static void
 et_set_property (GObject *object,
-		 guint prop_id,
-		 const GValue *value,
-		 GParamSpec *pspec)
+                 guint property_id,
+                 const GValue *value,
+                 GParamSpec *pspec)
 {
 	ETree *etree = E_TREE (object);
 
-	switch (prop_id) {
+	switch (property_id) {
 	case PROP_LENGTH_THRESHOLD:
 		etree->priv->length_threshold = g_value_get_int (value);
 		if (etree->priv->item) {
@@ -2048,8 +2121,8 @@ et_set_property (GObject *object,
 }
 
 gint
-e_tree_get_next_row      (ETree *e_tree,
-			   gint    model_row)
+e_tree_get_next_row (ETree *e_tree,
+                     gint model_row)
 {
 	g_return_val_if_fail (e_tree != NULL, -1);
 	g_return_val_if_fail (E_IS_TREE (e_tree), -1);
@@ -2062,16 +2135,22 @@ e_tree_get_next_row      (ETree *e_tree,
 			return e_sorter_sorted_to_model (E_SORTER (e_tree->priv->sorter), i);
 		} else
 			return -1;
-	} else
-		if (model_row < e_table_model_row_count (E_TABLE_MODEL (e_tree->priv->etta)) - 1)
+	} else {
+		gint row_count;
+
+		row_count = e_table_model_row_count (
+			E_TABLE_MODEL (e_tree->priv->etta));
+
+		if (model_row < row_count - 1)
 			return model_row + 1;
 		else
 			return -1;
+	}
 }
 
 gint
-e_tree_get_prev_row      (ETree *e_tree,
-			  gint    model_row)
+e_tree_get_prev_row (ETree *e_tree,
+                     gint model_row)
 {
 	g_return_val_if_fail (e_tree != NULL, -1);
 	g_return_val_if_fail (E_IS_TREE (e_tree), -1);
@@ -2089,8 +2168,8 @@ e_tree_get_prev_row      (ETree *e_tree,
 }
 
 gint
-e_tree_model_to_view_row        (ETree *e_tree,
-				  gint    model_row)
+e_tree_model_to_view_row (ETree *e_tree,
+                          gint model_row)
 {
 	g_return_val_if_fail (e_tree != NULL, -1);
 	g_return_val_if_fail (E_IS_TREE (e_tree), -1);
@@ -2102,8 +2181,8 @@ e_tree_model_to_view_row        (ETree *e_tree,
 }
 
 gint
-e_tree_view_to_model_row        (ETree *e_tree,
-				  gint    view_row)
+e_tree_view_to_model_row (ETree *e_tree,
+                          gint view_row)
 {
 	g_return_val_if_fail (e_tree != NULL, -1);
 	g_return_val_if_fail (E_IS_TREE (e_tree), -1);
@@ -2115,7 +2194,8 @@ e_tree_view_to_model_row        (ETree *e_tree,
 }
 
 gboolean
-e_tree_node_is_expanded (ETree *et, ETreePath path)
+e_tree_node_is_expanded (ETree *et,
+                         ETreePath path)
 {
 	g_return_val_if_fail (path, FALSE);
 
@@ -2123,7 +2203,9 @@ e_tree_node_is_expanded (ETree *et, ETreePath path)
 }
 
 void
-e_tree_node_set_expanded (ETree *et, ETreePath path, gboolean expanded)
+e_tree_node_set_expanded (ETree *et,
+                          ETreePath path,
+                          gboolean expanded)
 {
 	g_return_if_fail (et != NULL);
 	g_return_if_fail (E_IS_TREE (et));
@@ -2132,7 +2214,9 @@ e_tree_node_set_expanded (ETree *et, ETreePath path, gboolean expanded)
 }
 
 void
-e_tree_node_set_expanded_recurse (ETree *et, ETreePath path, gboolean expanded)
+e_tree_node_set_expanded_recurse (ETree *et,
+                                  ETreePath path,
+                                  gboolean expanded)
 {
 	g_return_if_fail (et != NULL);
 	g_return_if_fail (E_IS_TREE (et));
@@ -2141,7 +2225,8 @@ e_tree_node_set_expanded_recurse (ETree *et, ETreePath path, gboolean expanded)
 }
 
 void
-e_tree_root_node_set_visible (ETree *et, gboolean visible)
+e_tree_root_node_set_visible (ETree *et,
+                              gboolean visible)
 {
 	g_return_if_fail (et != NULL);
 	g_return_if_fail (E_IS_TREE (et));
@@ -2150,7 +2235,8 @@ e_tree_root_node_set_visible (ETree *et, gboolean visible)
 }
 
 ETreePath
-e_tree_node_at_row (ETree *et, gint row)
+e_tree_node_at_row (ETree *et,
+                    gint row)
 {
 	ETreePath path;
 
@@ -2160,7 +2246,8 @@ e_tree_node_at_row (ETree *et, gint row)
 }
 
 gint
-e_tree_row_of_node (ETree *et, ETreePath path)
+e_tree_row_of_node (ETree *et,
+                    ETreePath path)
 {
 	return e_tree_table_adapter_row_of_node (et->priv->etta, path);
 }
@@ -2172,7 +2259,8 @@ e_tree_root_node_is_visible (ETree *et)
 }
 
 void
-e_tree_show_node (ETree *et, ETreePath path)
+e_tree_show_node (ETree *et,
+                  ETreePath path)
 {
 	g_return_if_fail (et != NULL);
 	g_return_if_fail (E_IS_TREE (et));
@@ -2181,7 +2269,8 @@ e_tree_show_node (ETree *et, ETreePath path)
 }
 
 void
-e_tree_save_expanded_state (ETree *et, gchar *filename)
+e_tree_save_expanded_state (ETree *et,
+                            gchar *filename)
 {
 	g_return_if_fail (et != NULL);
 	g_return_if_fail (E_IS_TREE (et));
@@ -2190,7 +2279,8 @@ e_tree_save_expanded_state (ETree *et, gchar *filename)
 }
 
 void
-e_tree_load_expanded_state (ETree *et, gchar *filename)
+e_tree_load_expanded_state (ETree *et,
+                            gchar *filename)
 {
 	e_tree_table_adapter_load_expanded_state (et->priv->etta, filename);
 }
@@ -2205,7 +2295,8 @@ e_tree_save_expanded_state_xml (ETree *et)
 }
 
 void
-e_tree_load_expanded_state_xml (ETree *et, xmlDoc *doc)
+e_tree_load_expanded_state_xml (ETree *et,
+                                xmlDoc *doc)
 {
 	g_return_if_fail (et != NULL);
 	g_return_if_fail (E_IS_TREE (et));
@@ -2215,10 +2306,11 @@ e_tree_load_expanded_state_xml (ETree *et, xmlDoc *doc)
 }
 
 /* state: <0 ... collapse; 0 ... no force - use default; >0 ... expand;
-   when using this, be sure to reset to 0 once no forcing is required
-   anymore, aka the build of the tree is done */
+ * when using this, be sure to reset to 0 once no forcing is required
+ * anymore, aka the build of the tree is done */
 void
-e_tree_force_expanded_state (ETree *et, gint state)
+e_tree_force_expanded_state (ETree *et,
+                             gint state)
 {
 	e_tree_table_adapter_force_expanded_state (et->priv->etta, state);
 }
@@ -2236,7 +2328,11 @@ e_tree_get_tooltip (ETree *et)
 }
 
 static ETreePath
-find_next_in_range (ETree *et, gint start, gint end, ETreePathFunc func, gpointer data)
+find_next_in_range (ETree *et,
+                    gint start,
+                    gint end,
+                    ETreePathFunc func,
+                    gpointer data)
 {
 	ETreePath path;
 	gint row;
@@ -2251,7 +2347,11 @@ find_next_in_range (ETree *et, gint start, gint end, ETreePathFunc func, gpointe
 }
 
 static ETreePath
-find_prev_in_range (ETree *et, gint start, gint end, ETreePathFunc func, gpointer data)
+find_prev_in_range (ETree *et,
+                    gint start,
+                    gint end,
+                    ETreePathFunc func,
+                    gpointer data)
 {
 	ETreePath path;
 	gint row;
@@ -2363,7 +2463,7 @@ e_tree_get_table_adapter (ETree *et)
 }
 
 ETableItem *
-e_tree_get_item (ETree * et)
+e_tree_get_item (ETree *et)
 {
 	g_return_val_if_fail (et != NULL, NULL);
 	g_return_val_if_fail (E_IS_TREE (et), NULL);
@@ -2372,7 +2472,7 @@ e_tree_get_item (ETree * et)
 }
 
 GnomeCanvasItem *
-e_tree_get_header_item (ETree * et)
+e_tree_get_header_item (ETree *et)
 {
 	g_return_val_if_fail (et != NULL, NULL);
 	g_return_val_if_fail (E_IS_TREE (et), NULL);
@@ -2449,12 +2549,12 @@ struct _GtkDragSourceInfo
 /* Target */
 
 void
-e_tree_drag_get_data (ETree         *tree,
-		      gint             row,
-		      gint             col,
-		      GdkDragContext *context,
-		      GdkAtom         target,
-		      guint32         time)
+e_tree_drag_get_data (ETree *tree,
+                      gint row,
+                      gint col,
+                      GdkDragContext *context,
+                      GdkAtom target,
+                      guint32 time)
 {
 	g_return_if_fail (tree != NULL);
 	g_return_if_fail (E_IS_TREE (tree));
@@ -2477,8 +2577,8 @@ e_tree_drag_get_data (ETree         *tree,
  */
 void
 e_tree_drag_highlight (ETree *tree,
-		       gint     row,
-		       gint     col)
+                       gint row,
+                       gint col)
 {
 	GtkAllocation allocation;
 	GtkAdjustment *adjustment;
@@ -2587,7 +2687,11 @@ e_tree_drag_dest_unset (GtkWidget *widget)
 /* Source side */
 
 static gint
-et_real_start_drag (ETree *tree, gint row, ETreePath path, gint col, GdkEvent *event)
+et_real_start_drag (ETree *tree,
+                    gint row,
+                    ETreePath path,
+                    gint col,
+                    GdkEvent *event)
 {
 	GtkDragSourceInfo *info;
 	GdkDragContext *context;
@@ -2620,11 +2724,11 @@ et_real_start_drag (ETree *tree, gint row, ETreePath path, gint col, GdkEvent *e
 }
 
 void
-e_tree_drag_source_set  (ETree               *tree,
-			 GdkModifierType       start_button_mask,
-			 const GtkTargetEntry *targets,
-			 gint                  n_targets,
-			 GdkDragAction         actions)
+e_tree_drag_source_set (ETree *tree,
+                        GdkModifierType start_button_mask,
+                        const GtkTargetEntry *targets,
+                        gint n_targets,
+                        GdkDragAction actions)
 {
 	ETreeDragSourceSite *site;
 	GtkWidget *canvas;
@@ -2683,13 +2787,13 @@ e_tree_drag_source_unset (ETree *tree)
  */
 
 GdkDragContext *
-e_tree_drag_begin (ETree            *tree,
-		   gint	       row,
-		   gint	       col,
-		   GtkTargetList     *targets,
-		   GdkDragAction      actions,
-		   gint               button,
-		   GdkEvent          *event)
+e_tree_drag_begin (ETree *tree,
+                   gint row,
+                   gint col,
+                   GtkTargetList *targets,
+                   GdkDragAction actions,
+                   gint button,
+                   GdkEvent *event)
 {
 	ETreePath path;
 	g_return_val_if_fail (tree != NULL, NULL);
@@ -2721,8 +2825,10 @@ e_tree_drag_begin (ETree            *tree,
  **/
 void
 e_tree_get_cell_at (ETree *tree,
-		     gint x, gint y,
-		     gint *row_return, gint *col_return)
+                    gint x,
+                    gint y,
+                    gint *row_return,
+                    gint *col_return)
 {
 	GtkAdjustment *adjustment;
 	GtkScrollable *scrollable;
@@ -2768,9 +2874,12 @@ e_tree_get_cell_at (ETree *tree,
  **/
 void
 e_tree_get_cell_geometry (ETree *tree,
-			  gint row, gint col,
-			  gint *x_return, gint *y_return,
-			  gint *width_return, gint *height_return)
+                          gint row,
+                          gint col,
+                          gint *x_return,
+                          gint *y_return,
+                          gint *width_return,
+                          gint *height_return)
 {
 	GtkAdjustment *adjustment;
 	GtkScrollable *scrollable;
@@ -2802,8 +2911,8 @@ e_tree_get_cell_geometry (ETree *tree,
 
 static void
 et_drag_begin (GtkWidget *widget,
-	       GdkDragContext *context,
-	       ETree *et)
+               GdkDragContext *context,
+               ETree *et)
 {
 	g_signal_emit (et,
 		       et_signals[TREE_DRAG_BEGIN], 0,
@@ -2815,8 +2924,8 @@ et_drag_begin (GtkWidget *widget,
 
 static void
 et_drag_end (GtkWidget *widget,
-	     GdkDragContext *context,
-	     ETree *et)
+             GdkDragContext *context,
+             ETree *et)
 {
 	g_signal_emit (et,
 		       et_signals[TREE_DRAG_END], 0,
@@ -2828,11 +2937,11 @@ et_drag_end (GtkWidget *widget,
 
 static void
 et_drag_data_get (GtkWidget *widget,
-		 GdkDragContext *context,
-		 GtkSelectionData *selection_data,
-		 guint info,
-		 guint time,
-		 ETree *et)
+                  GdkDragContext *context,
+                  GtkSelectionData *selection_data,
+                  guint info,
+                  guint time,
+                  ETree *et)
 {
 	g_signal_emit (et,
 		       et_signals[TREE_DRAG_DATA_GET], 0,
@@ -2847,8 +2956,8 @@ et_drag_data_get (GtkWidget *widget,
 
 static void
 et_drag_data_delete (GtkWidget *widget,
-		    GdkDragContext *context,
-		    ETree *et)
+                     GdkDragContext *context,
+                     ETree *et)
 {
 	g_signal_emit (et,
 		       et_signals[TREE_DRAG_DATA_DELETE], 0,
@@ -2860,10 +2969,10 @@ et_drag_data_delete (GtkWidget *widget,
 
 static gboolean
 do_drag_motion (ETree *et,
-	       GdkDragContext *context,
-	       gint x,
-	       gint y,
-	       guint time)
+                GdkDragContext *context,
+                gint x,
+                gint y,
+                guint time)
 {
 	gboolean ret_val = FALSE;
 	gint row, col;
@@ -2964,9 +3073,11 @@ scroll_timeout (gpointer data)
 }
 
 static void
-scroll_on (ETree *et, guint scroll_direction)
+scroll_on (ETree *et,
+           guint scroll_direction)
 {
-	if (et->priv->scroll_idle_id == 0 || scroll_direction != et->priv->scroll_direction) {
+	if (et->priv->scroll_idle_id == 0 ||
+			scroll_direction != et->priv->scroll_direction) {
 		if (et->priv->scroll_idle_id != 0)
 			g_source_remove (et->priv->scroll_idle_id);
 		et->priv->scroll_direction = scroll_direction;
@@ -3017,7 +3128,9 @@ hover_timeout (gpointer data)
 }
 
 static void
-hover_on (ETree *et, gint x, gint y)
+hover_on (ETree *et,
+          gint x,
+          gint y)
 {
 	et->priv->hover_x = x;
 	et->priv->hover_y = y;
@@ -3036,11 +3149,13 @@ hover_off (ETree *et)
 }
 
 static void
-collapse_drag (ETree *et, ETreePath drop)
+collapse_drag (ETree *et,
+               ETreePath drop)
 {
 	GList *list;
 
-	/* We only want to leave open parents of the node dropped in.  Not the node itself. */
+	/* We only want to leave open parents of the node dropped in.
+	 * Not the node itself. */
 	if (drop) {
 		drop = e_tree_model_node_get_parent (et->priv->model, drop);
 	}
@@ -3074,7 +3189,8 @@ collapse_drag (ETree *et, ETreePath drop)
 }
 
 static void
-context_destroyed (gpointer data, GObject *ctx)
+context_destroyed (gpointer data,
+                   GObject *ctx)
 {
 	ETree *et = data;
 	if (et->priv) {
@@ -3090,13 +3206,16 @@ context_destroyed (gpointer data, GObject *ctx)
 }
 
 static void
-context_connect (ETree *et, GdkDragContext *context)
+context_connect (ETree *et,
+                 GdkDragContext *context)
 {
 	if (context == et->priv->last_drop_context)
 		return;
 
 	if (et->priv->last_drop_context)
-		g_object_weak_unref (G_OBJECT (et->priv->last_drop_context), context_destroyed, et);
+		g_object_weak_unref (
+			G_OBJECT (et->priv->last_drop_context),
+			context_destroyed, et);
 	else
 		g_object_ref (et);
 
@@ -3105,9 +3224,9 @@ context_connect (ETree *et, GdkDragContext *context)
 
 static void
 et_drag_leave (GtkWidget *widget,
-	      GdkDragContext *context,
-	      guint time,
-	      ETree *et)
+               GdkDragContext *context,
+               guint time,
+               ETree *et)
 {
 	g_signal_emit (et,
 		       et_signals[TREE_DRAG_LEAVE], 0,
@@ -3125,11 +3244,11 @@ et_drag_leave (GtkWidget *widget,
 
 static gboolean
 et_drag_motion (GtkWidget *widget,
-	       GdkDragContext *context,
-	       gint x,
-	       gint y,
-	       guint time,
-	       ETree *et)
+                GdkDragContext *context,
+                gint x,
+                gint y,
+                guint time,
+                ETree *et)
 {
 	GtkAllocation allocation;
 	gint ret_val;
@@ -3173,11 +3292,11 @@ et_drag_motion (GtkWidget *widget,
 
 static gboolean
 et_drag_drop (GtkWidget *widget,
-	     GdkDragContext *context,
-	     gint x,
-	     gint y,
-	     guint time,
-	     ETree *et)
+              GdkDragContext *context,
+              gint x,
+              gint y,
+              guint time,
+              ETree *et)
 {
 	gboolean ret_val = FALSE;
 	gint row, col;
@@ -3235,13 +3354,13 @@ et_drag_drop (GtkWidget *widget,
 
 static void
 et_drag_data_received (GtkWidget *widget,
-		      GdkDragContext *context,
-		      gint x,
-		      gint y,
-		      GtkSelectionData *selection_data,
-		      guint info,
-		      guint time,
-		      ETree *et)
+                       GdkDragContext *context,
+                       gint x,
+                       gint y,
+                       GtkSelectionData *selection_data,
+                       guint info,
+                       guint time,
+                       ETree *et)
 {
 	gint row, col;
 	ETreePath path;
@@ -3589,7 +3708,9 @@ e_tree_class_init (ETreeClass *class)
 }
 
 static void
-tree_size_allocate (GtkWidget *widget, GtkAllocation *alloc, ETree *tree)
+tree_size_allocate (GtkWidget *widget,
+                    GtkAllocation *alloc,
+                    ETree *tree)
 {
 	gdouble width;
 
@@ -3616,7 +3737,8 @@ tree_size_allocate (GtkWidget *widget, GtkAllocation *alloc, ETree *tree)
  * Creates an info message in table area, or removes old.
  **/
 void
-e_tree_set_info_message (ETree *tree, const gchar *info_message)
+e_tree_set_info_message (ETree *tree,
+                         const gchar *info_message)
 {
 	GtkAllocation allocation;
 	GtkWidget *widget;
